/*
 * ref: FreeRTOS V8.2.3
 * 
 * lmm
 * 03132017
 */

#include <stdlib.h>

#include "FreeRTOS.h"
#include "task.h"

#include "omsp.h"

#include "tasktags.h"
#include "lmm.h"

#define lmmSTACK_SIZE            ( configMINIMAL_STACK_SIZE ) // configMINIMAL_STACK_SIZE
#define lmmNUMBER_OF_TASKS       ( 1 )


#define ROW_NUM (3)
#define P_NUM (2)
#define COL_NUM (3)

#define LOOP_NUM (1)

#define P (56728)
#define Q (12344)

#define ELE_NUM (8)

#define LIST_LEN7 (20)

#define LIST_LEN8 (6)

//#define LIST_LEN10 (3)

typedef struct _node_t {
        int   v;
        struct _node_t * prev;
        struct _node_t * next;
}node_t;

//   slightly modified from glib-2.47.6/glist.c
#define gpointer int

typedef struct _GList {
        gpointer data;
        struct _GList *next;
        struct _GList *prev;
}GList;

const int a2[ROW_NUM*P_NUM] = {
                4, 5, 6, 7, 8, 9 // 1, 2, 3, 4, 5, 6, 7, 8, 9
};
const int b2[P_NUM*COL_NUM] = {
                11, 2, 13, 4, 15, 6 // 11, 2, 13, 4, 15, 6, 17, 8, 19
};
int c2[ROW_NUM*COL_NUM] = {
                0, 0, 0, 0, 0, 0, 0, 0, 0
};

float a3, b3, c3;

const int a5[ELE_NUM] = {
                234, 54, 1, 45, 90, 21, 231, 87
};

int a7[] = {5, 7, 15, 3, 1, 19, 11, 13, 17, 9};

node_t d7[LIST_LEN7];

const int a8[] = {5, 7, 91, 3, 1, 30, 52, 13, 67, 9};

GList d8[LIST_LEN8];

const char a9[] = {"rudjsifhsugjdjth3847reufhfssgsut3qwsdxdsdfgdhytj34te5yraq2w"};

//const int a10[] = {7, 91, 3, 1, 30, 52, 13, 67, 9};


static int gcd(int a, int b) {
        if(0 == b)
                return a;
        else
                return gcd(b, a % b);
}

void testqsort(int* arr, int n) {
        int i, j, t, pivot;
        pivot = arr[0];
        i = 1;
        j = n-1;
        if(n < 2)
                return;
        while(i < j) {
                if(arr[i] > pivot) {
                        if(arr[j] < pivot) {
                                t = arr[i];
                                arr[i] = arr[j];
                                arr[j] = t;
                                i ++;
                                j --;
                        }
                        else {
                                j --;
                        }
                }
                else {
                        i ++;
                }
        }
        t = arr[i];
        arr[i] = pivot;
        arr[0] = t;
        testqsort(arr, i - 1);
        testqsort(arr + i + 1, n - (i + 1));
}

static node_t* list_find(node_t* p, int t) {
        while (NULL != p) {
                if(t == p->v)
                        break;
                p = p->next;
        }
        return p;
}

static GList *
g_list_sort_merge (GList     *l1,
                GList     *l2)
{
        GList list, *l, *lprev;

        l = &list;
        lprev = NULL;

        while (l1 && l2)
        {
                if (l1->data <= l2->data)
                {
                        l->next = l1;
                        l1 = l1->next;
                }
                else
                {
                        l->next = l2;
                        l2 = l2->next;
                }
                l = l->next;
                l->prev = lprev;
                lprev = l;
        }
        l->next = l1 ? l1 : l2;
        l->next->prev = l;

        return list.next;
}

static GList *
g_list_sort_real (GList    *list)
{
        GList *l1, *l2;

        if (!list)
                return NULL;
        if (!list->next)
                return list;

        l1 = list;
        l2 = list->next;

        while ((l2 = l2->next) != NULL)
        {
                if ((l2 = l2->next) == NULL)
                        break;
                l1 = l1->next;
        }
        l2 = l1->next;
        l1->next = NULL;

        return g_list_sort_merge (g_list_sort_real (list),
                        g_list_sort_real (l2));
}

unsigned int
g_str_hash (const char *p)
{
        unsigned int h = 5381;

        for (; *p != '\0'; p++)
                h = (h << 5) + h + *p;

        return h;
}


static portTASK_FUNCTION_PROTO( vLMMTask, pvParameters );

/*-----------------------------------------------------------*/

void vStartLMMTasks( UBaseType_t uxPriority )
{
BaseType_t xTask;

        /* Create the three tasks. */
        for( xTask = 0; xTask < lmmNUMBER_OF_TASKS; ++xTask )
        {
                /* Spawn the task. */
                xTaskCreate( vLMMTask, "LMMx", lmmSTACK_SIZE, NULL, uxPriority, ( TaskHandle_t * ) NULL );
        }
}
/*-----------------------------------------------------------*/

static portTASK_FUNCTION( vLMMTask, pvParameters )
{
        int i, j, k, d;
        int a4, b4, c4;
        int b5[ELE_NUM];
        int state;
        node_t* head7;
        node_t* o7;
        GList* head8;
        GList* o8;
        unsigned int hash;
//        GList* head10;
//        GList* o10;

        for(;;)
        {
      
                taskENTER_CRITICAL(); // prevent preemption and interrupt
                a3 = 1.1;
                b3 = 0.9;

                a4 = P; b4 = Q; c4 = 0;

                for(i = 0; i < ELE_NUM; i ++) {
                        b5[i] = a5[i];
                }

                state = 1;

                head7 = &d7[0];
                head7->v = a7[0];
                head7->prev = NULL;
                o7 = head7;
                for (i = 1; i < LIST_LEN7; i ++) {
                        node_t* p7;
                        p7 = &d7[i];
                        p7->v = a7[i];
                        o7->next = p7;
                        p7->prev = o7;
                        p7->next = NULL;
                        o7 = p7;
                }
                o7 = NULL;

                head8 = &d8[0];
                head8->data = a8[0];
                head8->prev = NULL;
                o8 = head8;
                for (i = 1; i < LIST_LEN8; i ++) {
                        GList* p8;
                        p8 = &d8[i];
                        p8->data = a8[i];
                        o8->next = p8;
                        p8->prev = o8;
                        p8->next = NULL;
                        o8 = p8;
                }
                o8 = NULL;

                hash = 0;
/*
                head10 = NULL;
                o10 = NULL;*/
                
                i = 0; j = 0; k = 0; d = 0;

        asm volatile (  "push   r4                                              \n\t"   \
                                        "push   r5                                              \n\t"   \
                                        "push   r6                                              \n\t"   \
                                        "push   r7                                              \n\t"   \
                                        "push   r8                                              \n\t"   \
                                        "push   r9                                              \n\t"   \
                                        "push   r10                                             \n\t"   \
                                        "push   r11                                             \n\t"   \
                                        "push   r12                                             \n\t"   \
                                        "push   r13                                             \n\t"   \
                                        "push   r14                                             \n\t"   \
                                        "push   r15                                             \n\t"   \
                                );
asm("MOV #-7124, r4");
asm("MOV #-7415, r5");
asm("MOV #29715, r6");
asm("MOV #11850, r7");
asm("MOV #17480, r8");
asm("MOV #12730, r9");
asm("MOV #-32251, r10");
asm("MOV #-21184, r11");
asm("MOV #-16339, r12");
asm("MOV #32053, r13");
asm("MOV #-1890, r14");
asm("MOV #-10640, r15");
                asm("ADD #4, r4"); // clear flags
                toggleTask(LMM0_TAG);
                asm("nop");
                asm("nop");
                asm("nop");
                asm("nop");
                asm("nop");
                asm("nop");
asm("AND.B r5, r13");
asm("ADDC r6, r8");
asm("AND r4, r6");
asm("ADD r9, r8");
asm("ADD.B r12, r15");
asm("AND r6, r7");
asm("ADDC.B #-31261, r9");
asm("AND.B r15, r6");
asm("AND r10, r8");
asm("ADDC.B #12850, r4");
asm("ADDC r9, r6");
asm("ADD #-32634, r6");
asm("ADD.B #-21838, r5");
asm("AND #-21258, r10");
asm("AND #-32067, r9");
asm("AND #-14060, r15");
asm("AND.B #28321, r15");
asm("AND.B r4, r4");
asm("ADD.B #23572, r7");
asm("ADD.B r8, r7");
asm("ADD #914, r9");
asm("ADDC r15, r10");
asm("ADDC #14842, r15");
asm("AND r6, r12");
asm("ADDC #-32581, r4");
asm("ADD #9960, r13");
asm("AND r4, r15");
asm("AND r15, r9");
asm("ADDC #-27585, r6");
asm("ADD.B r4, r15");
asm("ADDC.B #-25006, r13");
asm("ADD.B r11, r14");
asm("ADDC.B r13, r9");
asm("AND.B #5995, r11");
asm("AND.B #5268, r14");
asm("ADDC #6968, r9");
asm("ADD r6, r7");
asm("ADD r6, r4");
asm("AND.B #-32265, r5");
asm("AND.B r8, r8");
asm("ADDC.B r7, r7");
asm("ADDC.B #-20318, r6");
asm("ADD.B #-9329, r4");
asm("AND r5, r11");
asm("ADD r15, r13");
asm("AND r8, r4");
asm("ADDC #3556, r9");
asm("ADDC r5, r10");
asm("AND r10, r14");
asm("ADD r13, r15");
asm("ADD.B #6933, r11");
asm("ADD r4, r11");
asm("AND.B #5336, r15");
asm("ADD #-3467, r13");
asm("ADD.B #-20833, r9");
asm("ADD.B #-11230, r12");
asm("ADDC.B #14513, r9");
asm("ADD.B r12, r13");
asm("ADD.B #26807, r8");
asm("ADD.B #-1787, r4");
asm("ADDC.B #-15704, r11");
asm("ADD.B r7, r13");
asm("AND.B r15, r11");
asm("AND #-1638, r7");
asm("ADDC.B #-21171, r10");
asm("ADD #-25324, r15");
asm("ADD r15, r10");
asm("AND.B #6153, r4");
asm("ADDC.B #-842, r4");
asm("ADD.B r6, r13");
asm("AND #-11306, r13");
asm("ADDC #-5997, r9");
asm("AND r9, r15");
asm("ADDC.B r14, r15");
asm("ADDC r15, r6");
asm("ADDC.B r13, r11");
asm("ADD #-19725, r6");
asm("ADD.B #17055, r5");
asm("ADDC.B r14, r9");
asm("ADD.B #-6559, r12");
asm("ADD r10, r5");
asm("ADD.B r8, r9");
asm("ADDC.B r14, r4");
asm("ADDC.B r11, r10");
asm("ADD.B #-16709, r7");
asm("ADD.B #6466, r4");
asm("ADDC.B #28929, r5");
asm("ADD #-26167, r4");
asm("ADD.B #-12954, r13");
asm("AND #-32353, r14");
asm("ADD #26937, r10");
asm("ADD.B #-32336, r13");
asm("ADDC #-23598, r12");
asm("ADD.B #7728, r6");
asm("ADDC.B r4, r6");
asm("ADDC r7, r4");
asm("ADD r11, r13");
asm("ADD #24844, r6");
asm("ADDC.B r11, r11");
asm("ADD #-19302, r9");
asm("ADD.B r13, r7");
asm("AND.B r5, r12");
asm("ADDC.B r11, r15");
asm("ADD.B r8, r9");
asm("ADDC #7492, r6");
asm("AND r6, r9");
asm("ADDC.B r13, r6");
asm("AND.B #23096, r4");
asm("ADDC #13549, r10");
asm("ADD r8, r12");
asm("ADD r8, r10");
asm("ADD #2555, r13");
asm("ADDC.B r13, r15");
asm("ADD.B #14799, r4");
asm("AND.B r5, r12");
asm("AND #-862, r11");
asm("AND #29649, r5");
asm("ADD.B r7, r12");
asm("ADDC.B r13, r13");
asm("AND r9, r12");
asm("AND.B r5, r12");
asm("AND.B r10, r12");
asm("ADDC #22369, r4");
asm("AND.B #25024, r6");
asm("ADDC r15, r11");
asm("ADD r11, r15");
asm("ADD.B r6, r6");
asm("ADD #-10646, r14");
asm("ADDC r6, r11");
asm("ADD.B #17066, r5");
asm("AND #-4048, r6");
asm("AND.B r12, r15");
asm("ADD r9, r10");
asm("ADD.B r8, r6");
asm("AND.B #18926, r11");
asm("AND #-18915, r11");
asm("ADDC r12, r4");
asm("ADDC #-7483, r11");
asm("AND r7, r11");
asm("AND.B r6, r7");
asm("ADDC.B r7, r8");
asm("ADDC.B r7, r8");
asm("ADD #1286, r11");
asm("ADD.B #-11708, r7");
asm("ADD r4, r7");
asm("ADDC.B #6484, r8");
asm("ADDC.B #6361, r14");
asm("AND.B r12, r12");
asm("ADD r14, r11");
asm("ADDC #6855, r10");
asm("ADD.B #17528, r8");
asm("ADD.B #-22741, r5");
asm("ADD r5, r6");
asm("ADDC r6, r11");
asm("ADD #-14976, r8");
asm("AND #-11366, r14");
asm("ADD r9, r10");
asm("ADD r9, r11");
asm("ADDC #31268, r5");
asm("ADDC.B #16876, r9");
asm("AND #-23072, r6");
asm("ADDC.B r13, r14");
asm("AND.B r4, r4");
asm("ADD r4, r10");
asm("ADDC.B #8277, r9");
asm("ADD #-16021, r12");
asm("ADDC r12, r9");
asm("ADD r12, r5");
asm("ADD.B #-8303, r13");
asm("ADD.B r5, r15");
asm("ADD r14, r5");
asm("ADD.B #-13294, r14");
asm("AND.B r8, r7");
asm("ADDC r14, r6");
asm("ADDC #-26969, r5");
asm("ADD #-27282, r12");
asm("AND #18492, r6");
asm("ADD #19089, r5");
asm("ADD.B #-12790, r11");
asm("ADDC #18487, r9");
asm("ADDC #16621, r15");
asm("ADDC #17875, r14");
asm("ADDC.B #-869, r15");
asm("AND #-3174, r4");
asm("ADDC.B #17807, r8");
asm("ADD.B r11, r7");
asm("AND #-11109, r11");
asm("AND r5, r6");
asm("AND r13, r9");
asm("ADD.B r13, r14");
asm("ADD #16966, r14");
asm("AND.B r6, r10");
asm("AND.B r14, r6");
asm("ADD r5, r12");
asm("AND #11224, r6");
asm("AND r10, r6");
asm("ADDC.B #-20090, r8");
asm("ADD.B #-11627, r15");
asm("AND.B r15, r6");
asm("ADDC r9, r7");
asm("ADDC.B #-17799, r14");
asm("ADDC.B #-10669, r15");
asm("ADD r11, r11");
asm("ADD.B r14, r11");
asm("AND #-15854, r4");
asm("ADDC #21427, r4");
asm("AND.B #32460, r12");
asm("ADD #-18341, r15");
asm("ADD.B r9, r13");
asm("AND r9, r15");
asm("ADDC r14, r14");
asm("ADD #-27711, r12");
asm("AND r13, r11");
asm("AND r10, r4");
asm("ADDC.B #-27916, r8");
asm("ADD r9, r8");
asm("AND.B r13, r13");
asm("AND.B r15, r14");
asm("ADD r12, r12");
asm("AND #-23160, r4");
asm("AND #-15982, r8");
asm("AND.B #8233, r12");
asm("ADD.B #-27942, r7");
asm("ADDC #-7873, r10");
asm("AND.B r8, r11");
asm("ADDC.B #-28070, r8");
asm("ADD #13927, r7");
asm("AND r5, r4");
asm("AND.B r10, r9");
asm("AND.B r11, r8");
asm("AND #-11335, r9");
asm("AND r7, r15");
asm("ADD #7553, r6");
asm("ADD #13722, r15");
asm("AND.B r9, r9");
asm("AND r15, r12");
asm("ADDC.B #16960, r9");
asm("AND #-4815, r10");
asm("ADDC.B #15730, r14");
asm("ADDC #7419, r8");
asm("ADDC.B r7, r10");
asm("ADDC #25088, r11");
asm("ADD.B #-18862, r5");
asm("AND r10, r9");
asm("ADDC #8323, r6");
asm("AND #18774, r11");
asm("ADDC.B r11, r13");
asm("AND.B r15, r8");
asm("ADD r6, r11");
asm("ADD #13902, r6");
asm("ADDC.B #-13076, r14");
asm("AND.B #-32336, r9");
asm("ADDC r7, r5");
asm("ADD r14, r4");
asm("ADDC #26790, r13");
asm("ADD r13, r10");
asm("AND #13767, r8");
asm("ADDC.B r12, r4");
asm("ADD #14746, r4");
asm("ADDC.B r11, r7");
asm("ADD.B #31533, r4");
asm("AND.B r14, r5");
asm("AND.B r13, r11");
asm("AND.B #-2440, r5");
asm("ADDC r5, r5");
asm("ADDC r4, r9");
asm("AND r4, r7");
asm("ADD.B r12, r5");
asm("ADD.B #-30326, r10");
asm("ADDC r15, r6");
asm("ADD r6, r7");
asm("ADDC #-9004, r9");
asm("ADD r9, r8");
asm("ADD.B r10, r4");
asm("ADD r13, r10");
asm("ADDC.B r11, r10");
asm("ADDC.B r11, r14");
asm("ADD.B r5, r6");
asm("AND #30831, r14");
asm("AND r14, r9");
asm("ADD r10, r10");
asm("AND.B #-28086, r5");
asm("ADD.B #-26263, r10");
asm("ADDC.B r15, r12");
asm("AND r6, r6");
asm("ADDC r10, r6");
asm("AND #-17127, r8");
asm("ADD.B #-10892, r11");
asm("ADD.B r8, r5");
asm("AND r6, r12");
asm("ADDC.B #-16191, r15");
asm("ADDC.B r8, r6");
asm("AND #18627, r13");
asm("ADDC #-26553, r15");
asm("AND #-11342, r9");
asm("AND.B #-21074, r10");
asm("AND.B r9, r15");
asm("ADDC #-1175, r11");
asm("AND #29000, r15");
asm("AND.B #28679, r13");
asm("ADD.B r11, r12");
asm("AND #-11616, r11");
asm("ADD #17058, r6");
asm("ADDC r6, r13");
asm("ADDC #-17606, r15");
asm("AND.B r10, r15");
asm("ADDC.B #-21584, r9");
asm("AND #-31124, r15");
asm("AND.B #-30051, r4");
asm("ADD r15, r7");
asm("ADD.B r6, r5");
asm("ADD r9, r7");
asm("ADD.B #5734, r9");
asm("ADD.B r14, r13");
asm("ADDC.B #30568, r11");
asm("ADD.B #-6928, r8");
asm("ADDC.B r10, r12");
asm("AND #7259, r10");
asm("ADD.B r7, r14");
asm("ADD #20658, r12");
asm("AND #2002, r12");
asm("AND #20985, r7");
asm("ADD.B r15, r6");
asm("AND.B r4, r8");
asm("ADD r8, r9");
asm("AND r13, r6");
asm("AND.B r15, r8");
asm("AND.B r14, r10");
asm("ADD #-28893, r11");
asm("AND.B r15, r14");
asm("ADDC.B r7, r9");
asm("AND.B r10, r13");
asm("ADD.B r4, r15");
asm("ADD #5858, r12");
asm("ADDC #5394, r10");
asm("ADDC.B #14223, r9");
asm("ADD.B r10, r7");
asm("ADDC r10, r7");
asm("ADDC.B r7, r11");
asm("AND r8, r8");
asm("ADD #22585, r5");
asm("ADDC.B r10, r6");
asm("ADD r13, r10");
asm("ADD r9, r4");
asm("ADD r6, r6");
asm("AND r5, r10");
asm("ADDC.B #-9773, r7");
asm("ADDC.B #27279, r10");
asm("ADD.B r11, r13");
asm("ADD.B #-13705, r13");
asm("ADDC #18118, r14");
asm("AND #-13929, r10");
asm("ADDC #-31398, r10");
asm("ADD #-7266, r14");
asm("ADDC.B #-24650, r10");
asm("AND r8, r12");
asm("ADDC r11, r15");
asm("ADDC.B #-17037, r14");
asm("ADD r13, r10");
asm("ADD r8, r13");
asm("ADDC #11069, r8");
asm("ADDC.B r13, r8");
asm("ADDC #21423, r5");
asm("ADD.B #19079, r7");
asm("ADDC.B #-24044, r14");
asm("ADD r6, r10");
asm("AND #25645, r4");
asm("AND.B r11, r4");
asm("ADDC.B r5, r8");
asm("ADD r14, r15");
asm("AND.B #7134, r12");
asm("AND r14, r9");
asm("ADDC.B r10, r6");
asm("ADDC #27505, r8");
asm("ADD.B r11, r9");
asm("ADD.B r14, r6");
asm("ADD #553, r4");
asm("ADD #-20325, r5");
asm("ADD.B #16455, r6");
asm("ADDC r4, r11");
asm("ADDC #25343, r8");
asm("ADD r15, r6");
asm("AND r9, r9");
asm("ADD r4, r5");
asm("ADDC.B #-1838, r8");
asm("ADDC #18569, r4");
asm("ADDC.B r4, r9");
asm("ADDC r11, r14");
asm("AND.B r8, r13");
asm("AND r12, r7");
asm("ADD #-12902, r11");
asm("ADDC.B r12, r5");
asm("ADDC.B #10741, r6");
asm("AND #26137, r5");
asm("AND #559, r15");
asm("AND r14, r9");
asm("AND r14, r11");
asm("ADDC.B #-31516, r5");
asm("ADDC r15, r7");
asm("ADD.B #-20689, r12");
asm("AND.B r9, r10");
asm("ADDC.B r13, r10");
asm("ADDC r15, r7");
asm("ADD #25621, r13");
asm("ADD r11, r11");
asm("ADDC.B r6, r4");
asm("ADD r9, r9");
asm("ADD r6, r6");
asm("ADDC #11456, r15");
asm("AND.B #31848, r11");
asm("ADD.B r14, r14");
asm("ADDC #29950, r4");
asm("ADDC r6, r4");
asm("ADD.B r13, r6");
asm("AND.B #24298, r12");
asm("ADD.B #17666, r5");
asm("ADDC #5391, r15");
asm("ADDC #-7714, r5");
asm("ADDC.B r5, r4");
asm("ADD.B #-552, r11");
asm("AND #17472, r8");
asm("ADDC.B r9, r15");
asm("ADDC #-12148, r6");
asm("ADDC.B #-22438, r5");
asm("ADD.B r15, r5");
asm("ADDC.B r4, r12");
asm("ADDC.B #5971, r10");
asm("ADD r5, r5");
asm("AND #5276, r9");
asm("ADDC #-29148, r13");
asm("AND r4, r15");
asm("ADDC.B r12, r6");
asm("ADDC #-11550, r11");
asm("ADD.B #-5347, r9");
asm("ADD.B #-14493, r13");
asm("ADDC #-902, r6");
asm("ADDC #2952, r11");
asm("ADDC #-13922, r4");
asm("AND.B #2495, r7");
asm("ADD r4, r14");
asm("ADD r10, r6");
asm("ADDC.B #1243, r15");
asm("AND r11, r7");
asm("AND r7, r10");
asm("ADD.B r15, r6");
asm("ADD #-21208, r10");
asm("ADDC.B #-12627, r12");
asm("ADDC.B #-20765, r11");
asm("ADD.B #27966, r10");
asm("AND.B r6, r13");
asm("ADDC.B r12, r5");
asm("AND r5, r11");
asm("AND #15614, r14");
asm("ADDC.B #3993, r7");
asm("ADD.B r6, r4");
asm("ADDC.B r9, r11");
asm("AND.B #-27781, r13");
asm("ADDC.B #-18481, r5");
asm("AND r4, r6");
asm("ADD.B #-21354, r7");
asm("ADD.B r7, r13");
asm("ADD.B r4, r4");
asm("ADD r10, r6");
asm("ADD.B r10, r11");
asm("ADDC #23361, r8");
asm("AND.B #22927, r8");
asm("ADDC.B #7627, r9");
asm("ADDC #-24844, r5");
asm("ADD #-27624, r13");
asm("ADD #24204, r7");
asm("AND #15128, r13");
asm("ADDC.B r11, r11");
asm("ADD #-14186, r6");
asm("ADD r6, r8");
asm("AND r6, r9");
asm("ADD.B r5, r6");
asm("ADD #11789, r7");
asm("ADDC r14, r12");
asm("ADD #20962, r5");
asm("ADD #-2240, r10");
asm("ADD #26259, r9");
asm("AND r12, r10");
asm("ADD.B r4, r13");
asm("ADDC.B #31191, r11");
asm("AND.B #1568, r10");
asm("AND.B r12, r8");
asm("ADD r15, r5");
asm("ADDC r12, r6");
asm("ADDC.B #-2724, r11");
asm("ADDC.B r11, r10");
asm("ADDC #-21117, r11");
asm("ADD #-1873, r8");
asm("ADDC.B r11, r13");
asm("AND r10, r14");
asm("ADD.B r4, r10");
asm("AND.B r9, r11");
asm("AND #-1838, r10");
asm("ADD #9388, r12");
asm("ADDC r9, r4");
asm("ADD r10, r6");
asm("AND r8, r9");
asm("AND #17346, r9");
asm("AND r8, r13");
asm("ADDC r7, r13");
asm("ADDC.B #21990, r10");
asm("ADDC.B r8, r12");
asm("ADD.B r7, r6");
asm("AND.B r14, r14");
asm("ADDC r14, r12");
asm("ADD #-12716, r5");
asm("AND r15, r4");
asm("ADD r15, r6");
asm("ADDC #15919, r12");
asm("ADD #25322, r5");
asm("ADDC.B #12445, r11");
asm("ADD #-20639, r12");
asm("ADD #31383, r4");
asm("AND r4, r7");
asm("AND.B #-6080, r6");
asm("AND.B #-11168, r5");
asm("ADD.B r10, r5");
asm("ADD.B r6, r13");
asm("AND r9, r13");
asm("ADDC r11, r9");
asm("AND.B r13, r13");
asm("ADD r4, r8");
asm("ADDC.B #-17886, r14");
asm("AND #-30377, r8");
asm("ADDC.B r9, r8");
asm("AND #-23197, r10");
asm("ADDC.B r4, r8");
asm("ADDC r6, r9");
asm("AND.B #-26251, r14");
asm("AND #-8199, r4");
asm("AND r14, r13");
asm("ADDC r14, r4");
asm("ADD.B r5, r14");
asm("ADD r10, r13");
asm("ADD.B #-10482, r10");
asm("ADD #32422, r11");
asm("ADD.B #20239, r12");
asm("ADDC r6, r9");
asm("ADD #-27373, r15");
asm("ADD r5, r14");
asm("ADD r6, r9");
asm("ADD.B r9, r9");
asm("ADD.B r7, r15");
asm("AND #198, r9");
asm("AND.B r15, r8");
asm("ADD #3110, r7");
asm("ADDC #13521, r6");
asm("ADD #-29129, r10");
asm("AND.B #-8840, r6");
asm("ADDC.B r11, r10");
asm("ADD r9, r13");
asm("ADDC #-22711, r10");
asm("ADD.B r10, r6");
asm("ADD #22232, r7");
asm("ADDC r4, r12");
asm("ADD.B #-21267, r12");
asm("ADD.B r15, r14");
asm("ADDC #26094, r7");
asm("ADD.B r14, r8");
asm("ADDC r15, r4");
asm("ADD.B #24344, r4");
asm("ADD.B #-25409, r7");
asm("ADD #-22461, r14");
asm("ADD.B #-13226, r9");
asm("ADDC #1285, r13");
asm("AND #22323, r10");
asm("ADD.B #24770, r8");
asm("ADDC #-24259, r7");
asm("ADD.B r4, r7");
asm("AND.B #10056, r14");
asm("ADD #-16087, r4");
asm("AND #5462, r10");
asm("AND.B r10, r9");
asm("ADD.B r10, r6");
asm("AND.B #2093, r6");
asm("AND r8, r13");
asm("ADDC #-19364, r11");
asm("AND.B r4, r7");
asm("ADDC.B r7, r10");
asm("AND r7, r14");
asm("AND.B r5, r7");
asm("ADDC #14291, r9");
asm("ADD #-21559, r10");
asm("ADD.B #20474, r6");
asm("ADD #28341, r8");
asm("ADD.B #-32495, r15");
asm("AND.B #-30333, r15");
asm("AND.B #12835, r11");
asm("ADD r13, r8");
asm("ADD #-15429, r13");
asm("ADD r13, r9");
asm("ADDC.B #-29547, r8");
asm("ADDC #-30701, r12");
asm("ADDC r6, r15");
asm("ADD.B #7461, r4");
asm("ADD r11, r5");
asm("AND.B r5, r6");
asm("ADDC #10319, r11");
asm("AND.B #-30583, r12");
asm("AND.B r10, r6");
asm("ADD.B r5, r15");
asm("ADD.B r15, r14");
asm("AND r15, r5");
asm("AND r9, r9");
asm("ADDC #-16541, r14");
asm("ADDC #-7796, r8");
asm("ADD #-28376, r11");
asm("ADD #-277, r10");
asm("ADD.B r9, r12");
asm("ADDC.B r12, r11");
asm("AND.B #-15641, r13");
asm("ADD.B #-30006, r13");
asm("AND.B #-31329, r8");
asm("ADD.B #1564, r11");
asm("ADD #24595, r14");
asm("ADD #29762, r8");
asm("AND.B r8, r12");
asm("AND.B #13385, r5");
asm("ADD.B #32705, r10");
asm("ADD r6, r14");
asm("AND.B r13, r13");
asm("ADDC r5, r14");
asm("ADD.B #-9064, r8");
asm("ADDC #30351, r7");
asm("ADD.B #15607, r10");
asm("AND.B #-1423, r15");
asm("AND.B #5985, r8");
asm("ADDC #-2850, r4");
asm("AND.B r6, r10");
asm("ADDC.B #-14120, r6");
asm("ADDC.B #-5646, r9");
asm("ADDC #-20942, r14");
asm("ADD r4, r15");
asm("ADD r13, r4");
asm("ADD #7097, r5");
asm("AND.B r15, r8");
asm("ADD #2489, r10");
asm("ADD.B #-23700, r10");
asm("ADDC r12, r4");
asm("AND.B r10, r13");
asm("ADD.B r6, r5");
asm("AND.B #-13657, r11");
asm("AND #-21023, r15");
asm("ADDC.B #17955, r9");
asm("AND r6, r12");
asm("AND.B #27973, r6");
asm("ADDC #30719, r9");
asm("ADD.B #631, r13");
asm("ADDC.B #6392, r12");
asm("ADDC r5, r10");
asm("ADD.B r12, r15");
asm("ADDC #-31229, r15");
asm("ADDC.B r10, r15");
asm("ADDC.B r13, r5");
asm("AND #22166, r11");
asm("ADDC r4, r14");
asm("AND.B r13, r9");
asm("AND r7, r15");
asm("ADDC #10960, r6");
asm("ADDC.B #-23524, r12");
asm("ADD.B #26873, r14");
asm("ADDC #-10237, r8");
asm("ADD r13, r11");
asm("AND.B #-17199, r13");
asm("ADDC.B r5, r13");
asm("AND.B r6, r12");
asm("AND r14, r6");
asm("ADDC r15, r13");
asm("ADD.B r11, r15");
asm("ADDC.B r14, r14");
asm("ADD.B #-2616, r9");
asm("ADDC #27557, r9");
asm("ADD.B #28931, r10");
asm("ADD #16064, r10");
asm("ADD #-29304, r9");
asm("AND #-16851, r7");
asm("AND #31750, r14");
asm("ADDC #-24294, r7");
asm("AND.B #7053, r6");
asm("ADDC.B r11, r9");
asm("ADDC.B #-14898, r5");
asm("ADD #-8826, r11");
asm("AND.B #-18855, r15");
asm("ADD.B r7, r14");
asm("AND.B #2420, r12");
asm("AND.B #16732, r7");
asm("AND #13073, r10");
asm("AND.B #-5371, r7");
asm("AND.B r9, r7");
asm("AND.B r14, r5");
asm("ADD.B r9, r10");
asm("AND.B r13, r13");
asm("AND #-25791, r10");
asm("ADDC #-28524, r4");
asm("ADDC #-25342, r15");
asm("ADD r8, r13");
asm("ADDC.B r6, r12");
asm("AND r15, r6");
asm("ADDC.B r10, r11");
asm("ADDC.B #23332, r9");
asm("ADDC.B #18241, r10");
asm("AND.B #-26015, r5");
asm("AND #-2744, r6");
asm("ADD #12604, r5");
asm("AND.B r6, r6");
asm("ADDC.B r4, r9");
asm("AND #26461, r15");
asm("ADDC.B #-17182, r10");
asm("ADD r6, r8");
asm("ADD r4, r8");
asm("AND #-8602, r4");
asm("ADDC.B r13, r14");
asm("ADDC #5897, r13");
asm("ADDC.B r11, r7");
asm("AND.B #-17969, r10");
asm("AND #-5689, r8");
asm("AND #-29132, r4");
asm("ADDC.B r15, r7");
asm("ADD.B r9, r12");
asm("AND r13, r7");
asm("ADD.B #-20169, r6");
asm("AND.B r10, r8");
asm("ADDC.B #-4325, r12");
asm("ADDC #-1823, r6");
asm("ADDC.B r11, r13");
asm("ADDC r6, r14");
asm("ADD r9, r9");
asm("ADD #21864, r12");
asm("AND r12, r5");
asm("ADD r14, r4");
asm("ADDC.B #16610, r4");
asm("ADDC #-3154, r4");
asm("ADD r15, r11");
asm("ADDC.B #31497, r12");
asm("ADDC.B #-218, r5");
asm("AND r7, r5");
asm("ADDC.B #-20953, r10");
asm("AND.B r7, r11");
asm("ADDC.B r4, r13");
asm("AND r13, r13");
asm("ADD.B #7538, r4");
asm("ADD #31211, r8");
asm("ADD r12, r6");
asm("AND r11, r10");
asm("ADD #-31384, r9");
asm("AND r7, r15");
asm("ADD.B #2546, r7");
asm("AND #-2680, r15");
asm("ADDC #2885, r11");
asm("ADDC #7356, r9");
asm("AND r6, r9");
asm("ADD r15, r10");
asm("ADDC.B #-20447, r8");
asm("ADD r5, r4");
asm("ADDC.B #32630, r10");
asm("ADDC.B r7, r10");
asm("AND.B r10, r13");
asm("ADD r14, r15");
asm("ADDC r8, r13");
asm("ADDC r8, r8");
asm("ADDC #-5984, r13");
asm("AND #-9913, r11");
asm("AND.B r12, r14");
asm("ADD.B r13, r8");
asm("ADD.B #22947, r15");
asm("ADD.B #-21679, r15");
asm("ADDC #801, r5");
asm("ADD.B #-18213, r6");
asm("AND r7, r14");
asm("AND.B #-4605, r8");
asm("AND #32450, r6");
asm("AND.B r4, r13");
asm("ADDC r14, r11");
asm("ADD r7, r10");
asm("ADD.B #4776, r7");
asm("AND.B #-24537, r4");
asm("ADDC r14, r13");
asm("ADDC.B #20946, r4");
asm("ADDC.B r13, r15");
asm("ADD.B #-26286, r5");
asm("ADDC.B r13, r5");
asm("ADDC.B #-9254, r13");
asm("ADD.B #-6958, r7");
asm("AND r8, r8");
asm("ADD.B #-22324, r14");
asm("ADDC #-10770, r11");
asm("ADDC.B r15, r8");
asm("AND #28670, r12");
asm("AND r15, r10");
asm("ADD r10, r8");
asm("ADDC r13, r5");
asm("ADDC.B #-29874, r14");
asm("AND.B #7823, r5");
asm("AND r12, r6");
asm("ADDC r14, r11");
asm("AND #-14464, r10");
asm("ADD.B #17197, r12");
asm("ADDC #12968, r13");
asm("ADD.B #-7314, r9");
asm("ADD #-29219, r8");
asm("ADDC.B r7, r14");
asm("ADD.B #-7325, r11");
asm("ADDC r7, r4");
asm("AND #-24577, r7");
asm("ADD.B #-7562, r5");
asm("ADDC r4, r12");
asm("ADD.B #-1672, r8");
asm("AND r15, r8");
asm("AND.B #-25817, r11");
asm("ADD.B r11, r14");
asm("ADDC.B r9, r10");
asm("ADD #15610, r4");
asm("AND #-9648, r12");
asm("ADD.B r6, r7");
asm("AND r12, r4");
asm("ADD.B #16533, r11");
asm("ADDC.B r14, r8");
asm("AND r12, r4");
asm("ADDC #1744, r13");
asm("ADD.B #30870, r4");
asm("ADD #-19747, r8");
asm("ADD #23367, r13");
asm("ADD.B r14, r15");
asm("ADDC #-12381, r13");
asm("AND r7, r4");
asm("AND r8, r9");
asm("ADDC #3276, r7");
asm("ADD.B #-15977, r14");
asm("ADD.B r11, r7");
asm("ADDC #-5645, r5");
asm("ADDC #-16489, r10");
asm("AND.B #4401, r14");
asm("ADDC #-6547, r14");
asm("ADD #-31548, r11");
asm("AND #-23248, r10");
asm("ADD r8, r15");
asm("AND.B r10, r13");
asm("ADD.B #11098, r9");
asm("ADD r6, r6");
asm("AND r7, r14");
asm("ADD r12, r14");
asm("ADDC #21099, r14");
asm("AND #5091, r5");
asm("ADDC.B r15, r11");
asm("ADDC #12443, r4");
asm("ADD.B #4326, r10");
asm("AND r15, r12");
asm("AND.B r10, r15");
asm("ADDC.B r14, r15");
asm("ADDC.B #15080, r7");
asm("ADDC r4, r9");
asm("AND #-2246, r8");
asm("ADDC.B #2034, r5");
asm("AND #20955, r11");
asm("ADDC.B #1728, r6");
asm("AND r13, r13");
asm("ADDC #-22223, r5");
asm("ADD #21714, r15");
asm("ADD #1066, r5");
asm("AND r15, r15");
asm("ADDC.B r5, r4");
asm("ADD #19776, r11");
asm("ADD r12, r11");
asm("ADDC #23586, r11");
asm("AND r15, r12");
asm("AND r15, r4");
asm("AND #-20778, r14");
asm("ADDC #-19912, r5");
asm("ADD #-15788, r4");
asm("ADD r4, r12");
asm("AND r12, r14");
asm("AND.B #-26900, r15");
asm("ADD.B #24925, r8");
asm("AND r10, r6");
asm("AND.B r13, r6");
asm("ADDC.B r11, r6");
asm("ADD.B #29991, r10");
asm("ADD.B r14, r9");
asm("ADDC r10, r15");
asm("AND.B r9, r13");
asm("ADDC.B r13, r4");
asm("ADDC #-10716, r14");
asm("ADD r5, r11");
asm("AND #6506, r13");
asm("AND r11, r4");
asm("ADDC #24825, r6");
asm("ADD.B r7, r10");
asm("ADDC.B r15, r12");
asm("AND r5, r6");
asm("ADDC r5, r12");
asm("AND r5, r14");
asm("AND.B r6, r10");
asm("ADDC.B #10044, r9");
asm("ADD.B #17630, r8");
asm("AND #27378, r9");
asm("ADDC.B #20239, r11");
asm("ADD r9, r12");
asm("ADDC #10230, r10");
asm("ADD r5, r15");
asm("AND #9282, r4");
asm("ADDC.B r5, r9");
asm("AND #-10754, r4");
asm("AND.B r13, r13");
asm("ADDC.B #-13956, r4");
asm("ADD.B r12, r11");
asm("AND.B #-21970, r9");
asm("ADDC #19751, r11");
asm("AND r11, r7");
asm("ADD r14, r6");
asm("ADD.B r12, r8");
asm("ADDC.B #19699, r12");
asm("ADD.B r14, r15");
asm("AND.B #26537, r5");
asm("ADDC.B #22923, r9");
asm("ADDC.B r5, r7");
asm("AND #13217, r9");
asm("ADD.B r13, r7");
asm("AND r8, r5");
asm("ADDC #27593, r14");
asm("ADDC r5, r10");
asm("ADDC.B r5, r13");
asm("AND.B r11, r10");
asm("ADDC.B r14, r4");
asm("AND.B r15, r7");
asm("ADD #7029, r5");
asm("AND #-2157, r9");
asm("AND #14631, r14");
asm("AND.B #28307, r5");
asm("ADDC.B r9, r4");
asm("ADDC r10, r14");
asm("ADD.B r10, r7");
asm("ADD.B #25317, r6");
asm("ADDC.B #16686, r11");
asm("ADD r7, r13");
asm("ADD #3230, r6");
asm("ADDC.B #2234, r12");
asm("ADD #12129, r9");
asm("ADDC r11, r10");
asm("ADDC r12, r4");
asm("ADDC.B r6, r10");
asm("AND.B #-2852, r7");
asm("AND #9597, r12");
asm("AND.B r8, r7");
asm("AND #-14523, r14");
asm("ADD #-17517, r10");
asm("AND.B #28447, r6");
asm("ADD #-10028, r12");
asm("ADD #-14757, r5");
asm("ADD #10005, r14");
asm("ADDC.B r5, r12");
asm("ADDC r11, r4");
asm("AND.B r12, r14");
asm("AND #4398, r4");
asm("ADDC.B r15, r9");
asm("ADD.B r7, r7");
asm("ADD #-25052, r6");
asm("AND #2232, r5");
asm("AND #29326, r12");
asm("AND #-18402, r7");
asm("AND.B r8, r11");
asm("ADD.B #-7670, r14");
asm("ADD.B r7, r15");
asm("ADDC #18831, r10");
asm("ADDC r10, r14");
asm("ADD r12, r5");
asm("ADD.B r10, r7");
asm("ADD.B r14, r5");
asm("ADDC.B r15, r12");
asm("ADDC #25404, r15");
asm("ADDC #-10026, r11");
asm("ADD.B r9, r7");
asm("ADDC.B r4, r5");
asm("ADDC.B r4, r6");
asm("ADDC r5, r9");
asm("ADD.B #5462, r13");
asm("ADD.B r14, r5");
asm("AND.B r8, r13");
asm("ADDC.B #3865, r8");
asm("ADDC r4, r13");
asm("ADDC r4, r9");
asm("AND.B r7, r5");
asm("ADD.B r12, r7");
asm("ADD.B #-22649, r10");
asm("ADD.B r7, r8");
asm("AND.B r12, r15");
asm("AND.B r4, r12");
asm("ADDC.B #30873, r11");
asm("AND.B #-8114, r4");
asm("AND.B #-6031, r14");
asm("ADDC.B #23001, r9");
asm("ADDC r5, r10");
asm("AND #-15989, r5");
asm("ADD r9, r11");
asm("AND.B r14, r5");
asm("ADD.B #-30498, r5");
asm("ADD.B #-7111, r9");
asm("AND r6, r13");
asm("ADDC.B #28274, r15");
asm("ADD #-27175, r15");
asm("ADD #-17069, r7");
asm("ADDC r8, r15");
asm("ADD.B r14, r7");
asm("ADDC r7, r10");
asm("ADDC r9, r8");
asm("AND.B r8, r8");
asm("ADD r8, r13");
asm("AND #23211, r11");
asm("ADD.B #-16135, r9");
asm("ADD.B #16128, r10");
asm("AND.B #4100, r11");
asm("ADD.B #30228, r15");
asm("ADD.B #5572, r13");
asm("AND.B #11930, r7");
asm("ADD.B r14, r15");
asm("ADD.B r7, r14");
asm("ADDC.B r10, r9");
asm("ADD.B r7, r15");
asm("ADDC.B r14, r6");
asm("ADDC.B #-8606, r5");
asm("ADD r15, r4");
asm("ADD #-12464, r7");
asm("ADDC.B r6, r9");
asm("ADDC.B r13, r10");
asm("AND.B #-28338, r10");
asm("ADDC r14, r6");
asm("ADDC.B r11, r13");
asm("ADD.B r12, r11");
asm("ADDC r10, r8");
asm("AND #-7917, r8");
asm("AND r12, r11");
asm("ADD #-24329, r14");
asm("AND #15161, r10");
asm("ADD r10, r15");
asm("ADDC.B #19989, r14");
asm("ADDC.B r11, r8");
asm("ADD r14, r7");
asm("ADDC.B #19104, r4");
asm("ADD r13, r11");
asm("ADDC.B #-2028, r6");
asm("AND #-18206, r4");
asm("AND.B r8, r11");
asm("ADD.B #-15189, r15");
asm("ADDC r5, r15");
asm("ADD.B r10, r7");
asm("ADDC.B r9, r12");
asm("AND.B #23352, r12");
asm("ADDC.B #-24600, r11");
asm("AND.B #5330, r8");
asm("ADDC.B #2159, r15");
asm("ADDC.B r13, r8");
asm("ADDC #25470, r15");
asm("AND.B r13, r4");
asm("ADDC #20633, r11");
asm("ADDC.B #-4871, r12");
asm("ADD.B r4, r8");
asm("ADD.B r10, r4");
asm("ADDC.B r9, r12");
asm("ADDC.B r12, r6");
asm("ADD #-24200, r11");
asm("ADD.B #-28683, r7");
asm("ADD #3268, r4");
asm("ADDC.B r10, r9");
asm("ADDC.B r4, r9");
asm("AND.B r9, r15");
asm("ADDC #-25444, r11");
asm("ADD.B #1620, r6");
asm("AND.B #-14581, r14");
asm("ADD #15364, r5");
asm("AND.B r14, r15");
asm("ADD r8, r5");
asm("AND.B r15, r15");
asm("ADD.B #-21150, r5");
asm("ADD #-1548, r6");
asm("ADD r11, r15");
asm("ADD #-16676, r11");
asm("ADDC r12, r6");
asm("ADDC #13365, r15");
asm("ADD.B #24545, r4");
asm("ADDC r4, r11");
asm("AND.B #13786, r7");
asm("ADD #-31349, r6");
asm("ADDC r13, r5");
asm("AND.B r12, r7");
asm("AND.B #-4701, r6");
asm("ADD #-23545, r13");
asm("ADDC.B #31208, r6");
asm("ADD r11, r4");
asm("AND.B #30242, r8");
asm("ADD #11046, r6");
asm("AND.B r13, r8");
asm("ADD #-7726, r10");
asm("ADD.B r13, r8");
asm("AND #-19990, r7");
asm("ADDC.B #1442, r6");
asm("ADD.B #3841, r11");
asm("ADDC.B #-21361, r8");
asm("AND #-3686, r13");
asm("AND #-10412, r7");
asm("ADDC r12, r7");
asm("ADD.B r11, r14");
asm("AND.B r13, r12");
asm("ADD r4, r14");
asm("ADD r8, r5");
asm("ADDC.B #13407, r12");
asm("AND.B #27864, r12");
asm("ADD #-24775, r14");
asm("AND.B r7, r8");
asm("ADD.B r12, r13");
asm("ADD.B r5, r8");
asm("AND.B #23234, r10");
asm("ADD.B r8, r8");
asm("ADDC.B r10, r4");
asm("ADD #-15027, r15");
asm("ADDC.B #20596, r14");
asm("ADDC.B #6004, r5");
asm("ADDC.B r4, r8");
asm("ADDC #-30523, r14");
asm("AND.B r14, r6");
asm("ADD #559, r14");
asm("ADD.B #16570, r11");
asm("ADDC.B r4, r10");
asm("AND r10, r8");
asm("ADDC #-9232, r15");
asm("ADD.B #-16060, r4");
asm("ADD.B #-27279, r14");
asm("AND.B #-9221, r4");
asm("AND.B #21441, r6");
asm("AND #-32251, r14");
asm("AND.B #19438, r11");
asm("ADDC.B r13, r7");
asm("ADD.B #27294, r11");
asm("AND r6, r15");
asm("ADD #2647, r4");
asm("AND #-32392, r10");
asm("ADD.B #-10777, r5");
asm("ADD #32058, r12");
asm("ADDC r5, r6");
asm("ADD r4, r8");
asm("AND.B r15, r11");
asm("AND.B #30816, r4");
asm("AND r10, r7");
asm("AND.B #-21553, r9");
asm("ADDC r12, r6");
asm("ADD #-12674, r9");
asm("ADDC #23493, r4");
asm("ADD r9, r6");
asm("AND.B #25498, r13");
asm("ADD.B #2614, r14");
asm("ADDC.B r7, r6");
asm("AND r12, r15");
asm("ADDC #-10368, r9");
asm("AND r7, r6");
asm("AND.B r9, r9");
asm("ADD.B #24930, r7");
asm("AND.B #998, r8");
asm("ADDC.B r6, r13");
asm("ADDC.B r12, r5");
asm("ADDC r9, r13");
asm("ADDC.B r11, r6");
asm("ADDC.B r5, r13");
asm("AND.B #-21105, r12");
asm("ADDC r11, r6");
asm("AND.B #-22908, r9");
asm("AND.B r11, r14");
asm("ADD.B #-29991, r11");
asm("ADD #-8550, r13");
asm("ADD #-6366, r13");
asm("ADD.B #-9642, r9");
asm("ADDC r11, r15");
asm("AND.B r13, r6");
asm("ADDC.B r13, r6");
asm("ADD r7, r10");
asm("ADDC.B #-342, r9");
asm("ADD #-5740, r9");
asm("ADD.B r7, r4");
asm("AND.B r4, r9");
asm("ADDC.B #16392, r12");
asm("ADD.B #21916, r5");
asm("ADD.B #-2390, r9");
asm("ADDC #-87, r9");
asm("AND r12, r9");
asm("ADD r9, r14");
asm("ADD.B r10, r7");
asm("ADD r15, r9");
asm("ADDC #20589, r8");
asm("ADD #-23867, r9");
asm("ADDC.B r8, r7");
asm("ADD.B r7, r10");
asm("AND.B r5, r5");
asm("ADD.B r10, r4");
asm("ADD.B r9, r12");
asm("ADDC.B #-24427, r12");
asm("AND.B #28110, r9");
asm("AND #1991, r15");
asm("ADD r8, r15");
asm("ADD r10, r11");
asm("AND.B #-22838, r11");
asm("ADDC r15, r12");
asm("AND.B r6, r14");
asm("ADDC r4, r4");
asm("ADDC.B r5, r10");
asm("AND #3668, r5");
asm("AND #-26743, r4");
asm("ADD.B #-3487, r9");
asm("ADDC #21253, r14");
asm("ADD.B r14, r4");
asm("ADD r12, r11");
asm("ADD.B #24977, r7");
asm("AND.B r6, r11");
asm("ADDC r12, r8");
asm("ADDC.B r11, r13");
asm("ADD.B #6257, r13");
asm("ADDC.B r6, r8");
asm("AND.B #8260, r7");
asm("AND #-16843, r5");
asm("ADD.B r4, r5");
asm("ADD.B r14, r4");
asm("ADDC.B #32523, r7");
asm("ADD.B r8, r15");
asm("ADD #25997, r7");
asm("ADD #-5884, r13");
asm("AND.B #-8959, r10");
asm("ADDC #-29346, r15");
asm("AND r7, r9");
asm("ADDC.B #-15119, r11");
asm("AND #18584, r7");
asm("AND.B r4, r7");
asm("ADD #-27704, r14");
asm("AND r9, r14");
asm("ADD r9, r14");
asm("ADDC.B #6930, r15");
asm("ADDC #-12388, r4");
asm("ADDC.B r11, r7");
asm("ADD r14, r8");
asm("ADD.B r5, r14");
asm("AND #7218, r8");
asm("ADDC #-29493, r14");
asm("ADD.B #-3869, r13");
asm("ADD #13383, r11");
asm("AND r9, r11");
asm("ADDC #17923, r6");
asm("AND.B r11, r11");
asm("AND.B r4, r9");
asm("ADD.B #-18213, r12");
asm("ADDC.B r12, r9");
asm("ADDC.B r9, r9");
asm("ADD r12, r10");
asm("AND #-15802, r7");
asm("AND #-10572, r5");
asm("ADDC.B #-25583, r10");
asm("ADD #16637, r11");
asm("ADDC.B r4, r11");
asm("AND r15, r9");
asm("AND.B #-6841, r9");
asm("AND.B r10, r8");
asm("AND.B r11, r6");
asm("AND #18766, r8");
asm("AND r10, r7");
asm("ADDC r6, r10");
asm("ADDC #14592, r14");
asm("ADD #-15063, r14");
asm("AND r14, r7");
asm("ADDC #-14070, r11");
asm("ADDC.B #10038, r6");
asm("ADD.B #-5050, r5");
asm("AND r13, r9");
asm("ADD #27868, r12");
asm("ADDC r14, r11");
asm("ADDC r10, r12");
asm("AND r10, r7");
asm("ADDC #22145, r8");
asm("ADDC.B r6, r10");
asm("ADD r13, r13");
asm("ADDC #-10166, r11");
asm("ADDC #13737, r6");
asm("ADDC.B r6, r8");
asm("AND r13, r15");
asm("AND.B r4, r11");
asm("AND #388, r10");
asm("ADD.B r6, r12");
asm("ADD.B r5, r9");
asm("AND.B #4933, r11");
asm("AND r11, r14");
asm("ADDC.B r11, r13");
asm("ADDC r6, r9");
asm("AND.B r7, r9");
asm("AND.B r9, r13");
asm("AND #-27843, r13");
asm("ADDC.B r12, r15");
asm("AND #4249, r13");
asm("AND r12, r12");
asm("ADD.B r4, r5");
asm("ADD #-15060, r12");
asm("AND.B #9785, r9");
asm("ADDC r9, r13");
asm("AND #16781, r12");
asm("ADDC #23901, r15");
asm("ADD.B #-26355, r9");
asm("ADD r8, r11");
asm("ADD.B #-2328, r8");
asm("ADD r8, r5");
asm("AND.B #-24127, r9");
asm("ADD.B r13, r7");
asm("AND #20382, r12");
asm("ADD #26668, r15");
asm("ADD.B #-4915, r13");
asm("ADDC.B r9, r4");
asm("ADD #-9850, r12");
asm("ADD r8, r12");
asm("AND #29941, r13");
asm("ADD #1328, r4");
asm("ADD r5, r8");
asm("ADDC #-13123, r15");
asm("AND #-18865, r10");
asm("ADDC.B #4144, r8");
asm("ADDC.B r9, r13");
asm("AND #18695, r15");
asm("ADD #-1613, r5");
asm("ADD #7267, r6");
asm("ADDC.B #-23305, r9");
asm("ADD.B r7, r7");
asm("ADD #-25970, r12");
asm("ADD.B #27456, r10");
asm("AND #6939, r14");
asm("AND #3504, r5");
asm("ADDC r6, r9");
asm("AND.B #22485, r8");
asm("ADD r8, r10");
asm("AND #-17386, r7");
asm("AND #-3026, r14");
asm("ADD.B r13, r13");
asm("AND.B r11, r10");
asm("ADD.B r4, r11");
asm("AND.B #17149, r14");
asm("ADDC.B r5, r6");
asm("ADDC #30877, r7");
asm("ADDC r7, r14");
asm("AND #20993, r13");
asm("AND r7, r5");
asm("ADD #-65, r6");
asm("ADDC.B #9357, r9");
asm("ADD.B #-11428, r13");
asm("ADDC.B #25315, r13");
asm("ADD.B r5, r8");
asm("AND r14, r6");
asm("AND.B r5, r11");
asm("ADD r10, r5");
asm("ADD r15, r13");
asm("ADDC.B #17706, r12");
asm("AND.B r13, r4");
asm("ADDC r13, r12");
asm("ADDC #-31737, r13");
asm("AND.B r12, r14");
asm("AND.B #21997, r13");
asm("ADDC #-23525, r6");
asm("ADD r8, r4");
asm("AND r5, r14");
asm("AND.B #-1149, r4");
asm("AND #-21098, r4");
asm("ADDC r4, r9");
asm("AND.B r15, r12");
asm("AND r13, r8");
asm("ADDC #32753, r11");
asm("ADDC #-7144, r8");
asm("AND r9, r12");
asm("ADD.B #20992, r7");
asm("AND #9663, r4");
asm("ADD.B #21928, r4");
asm("ADDC.B #-23193, r7");
asm("ADDC #7954, r12");
asm("AND.B #-14616, r10");
asm("AND #-7276, r5");
asm("ADD r11, r13");
asm("AND.B r7, r4");
asm("AND r6, r5");
asm("ADD.B r13, r8");
asm("ADDC #12289, r12");
asm("ADD.B #-13294, r14");
asm("ADDC #11342, r11");
asm("ADD r12, r11");
asm("ADD r15, r14");
asm("ADDC.B r7, r7");
asm("ADDC r12, r8");
asm("AND #26705, r12");
asm("ADD r9, r14");
asm("AND.B r12, r8");
asm("AND.B #28913, r4");
asm("ADDC.B r8, r7");
asm("AND r9, r14");
asm("AND.B #9464, r11");
asm("ADD #11195, r6");
asm("AND.B #2687, r7");
asm("ADDC r13, r10");
asm("ADD #18201, r5");
asm("ADDC r10, r8");
asm("ADDC.B r15, r8");
asm("ADD #28348, r11");
asm("AND #-12663, r11");
asm("AND.B r9, r10");
asm("ADD.B r12, r10");
asm("ADD r6, r9");
asm("ADD #-1780, r5");
asm("ADDC.B #-24199, r11");
asm("AND r14, r14");
asm("ADDC.B r4, r8");
asm("ADD.B r7, r11");
asm("AND #-9351, r11");
asm("ADDC.B r10, r6");
asm("ADD.B #14274, r8");
asm("AND r4, r15");
asm("ADD.B #31126, r4");
asm("AND r6, r4");
asm("AND r13, r8");
asm("AND #28065, r13");
asm("AND #-14385, r13");
asm("AND.B #24376, r11");
asm("ADD.B r15, r10");
asm("ADDC.B r9, r5");
asm("ADDC.B #22225, r15");
asm("AND.B #21977, r12");
asm("ADD r6, r10");
asm("ADD #4809, r7");
asm("ADD.B #11118, r8");
asm("ADD #-28476, r15");
asm("ADD r12, r13");
asm("AND.B #9817, r9");
asm("ADDC r8, r13");
asm("AND.B r11, r5");
asm("ADDC #-16552, r7");
asm("ADDC.B r9, r14");
asm("ADD.B #19498, r10");
asm("ADDC.B r4, r4");
asm("AND.B r12, r9");
asm("ADD.B r14, r14");
asm("AND r10, r6");
asm("ADD.B #14783, r9");
asm("ADDC.B r7, r15");
asm("ADD.B #-23582, r9");
asm("ADDC #139, r8");
asm("ADD #28230, r7");
asm("ADDC r5, r11");
asm("AND #734, r6");
asm("AND #16236, r4");
asm("AND.B r5, r15");
asm("ADDC.B #23006, r6");
asm("ADD.B r13, r14");
asm("ADDC r8, r10");
asm("AND.B r10, r8");
asm("AND r9, r15");
asm("ADDC r5, r7");
asm("AND r14, r10");
asm("ADDC.B r6, r8");
asm("ADD.B #22603, r15");
asm("ADD #-2066, r12");
asm("AND.B #18815, r12");
asm("ADDC r14, r6");
asm("ADD #-29810, r8");
asm("ADDC.B r13, r9");
asm("AND.B #-15826, r6");
asm("ADD #-18320, r14");
asm("AND.B r12, r8");
asm("AND.B r4, r6");
asm("AND.B r15, r5");
asm("ADD.B r4, r9");
asm("ADDC.B #-22004, r12");
asm("ADD.B #-25020, r8");
asm("AND #-6774, r12");
asm("ADDC #-9532, r7");
asm("AND.B #-11985, r9");
asm("ADD r13, r15");
asm("AND r10, r9");
asm("ADD r9, r7");
asm("ADDC #16828, r6");
asm("ADD #-13707, r9");
asm("ADD #-25674, r9");
asm("AND.B #26203, r13");
asm("ADD #5328, r15");
asm("ADDC.B #13746, r4");
asm("ADD #-4054, r13");
asm("ADD.B #29354, r7");
asm("AND #-28448, r9");
asm("ADD.B #-23802, r15");
asm("ADDC.B #-10838, r7");
asm("AND #-4920, r12");
asm("ADDC.B #-782, r8");
asm("ADDC r9, r11");
asm("ADDC.B r7, r10");
asm("AND r6, r12");
asm("ADDC r12, r7");
asm("ADD.B r7, r4");
asm("ADDC.B r13, r13");
asm("ADDC r8, r14");
asm("AND.B r15, r13");
asm("ADD #20663, r5");
asm("ADD r11, r10");
asm("ADDC #26657, r10");
asm("AND.B r11, r14");
asm("AND #7789, r10");
asm("ADDC r12, r10");
asm("ADDC r12, r13");
asm("AND #12962, r14");
asm("ADD #25546, r13");
asm("ADDC #19078, r5");
asm("ADD.B #-30179, r9");
asm("ADDC.B r4, r9");
asm("ADDC r7, r8");
asm("ADDC r13, r8");
asm("AND r4, r14");
asm("ADD.B #-22812, r9");
asm("ADD.B r8, r8");
asm("ADD.B #-29247, r11");
asm("ADD.B r8, r7");
asm("ADDC.B #2046, r9");
asm("ADDC #-8698, r10");
asm("ADDC #-24682, r4");
asm("AND r15, r15");
asm("ADD.B r5, r10");
asm("ADD.B #19985, r4");
asm("ADDC r13, r9");
asm("AND #13224, r10");
asm("ADDC.B r11, r11");
asm("AND.B r12, r13");
asm("AND r4, r14");
asm("AND r5, r9");
asm("AND.B r13, r8");
asm("AND #5145, r14");
asm("ADD.B #-8845, r10");
asm("ADDC r13, r12");
asm("ADDC r8, r5");
asm("ADD.B r15, r4");
asm("ADD r5, r4");
asm("ADDC.B #18437, r11");
asm("ADD.B #-20159, r11");
asm("AND #-16291, r13");
asm("ADDC r5, r13");
asm("ADD.B r12, r12");
asm("ADDC #5663, r13");
asm("ADD #-19725, r6");
asm("AND.B r12, r11");
asm("ADDC #1899, r6");
asm("ADDC.B r5, r11");
asm("AND.B #-30026, r13");
asm("ADDC.B #-30642, r7");
asm("AND.B #24285, r4");
asm("ADDC r15, r5");
asm("ADDC r15, r11");
asm("ADD r6, r13");
asm("ADDC r4, r10");
asm("ADDC.B #-11081, r4");
asm("ADD r11, r8");
asm("AND r9, r6");
asm("AND r7, r13");
asm("ADD.B #-32294, r11");
asm("AND r6, r14");
asm("ADDC r11, r13");
asm("AND.B r15, r14");
asm("ADDC.B r10, r9");
asm("AND r4, r8");
asm("ADDC r6, r15");
asm("AND.B #23695, r14");
asm("ADDC.B r10, r6");
asm("ADDC #-10059, r15");
asm("AND.B #-28470, r13");
asm("ADDC r15, r8");
asm("AND.B #8196, r5");
asm("ADD r11, r15");
asm("AND.B #11819, r13");
asm("AND r8, r11");
asm("ADD #1575, r10");
asm("ADDC #-11539, r7");
asm("ADD #-28853, r14");
asm("AND r5, r14");
asm("ADD #-24272, r6");
asm("AND.B r15, r13");
asm("ADDC.B r14, r11");
asm("ADDC.B #-6554, r14");
asm("AND.B r9, r10");
asm("AND.B r6, r14");
asm("ADD.B #-12812, r8");
asm("AND.B #20372, r12");
asm("ADDC #-30218, r6");
asm("ADDC r6, r7");
asm("ADDC r8, r6");
asm("ADDC.B r12, r8");
asm("ADD r12, r9");
asm("ADD.B r7, r13");
asm("AND.B #29410, r10");
asm("ADD r5, r5");
asm("ADDC.B #26096, r13");
asm("ADD.B #-29318, r5");
asm("ADDC.B r6, r5");
asm("AND.B r12, r5");
asm("AND #30028, r10");
asm("ADDC.B #21339, r4");
asm("AND #6563, r7");
asm("AND r10, r9");
asm("ADD.B r7, r9");
asm("ADD.B #-27648, r11");
asm("AND r13, r6");
asm("AND.B r14, r8");
asm("ADD #1794, r11");
asm("AND.B #19904, r14");
asm("AND r9, r10");
asm("ADD r10, r9");
asm("ADDC r10, r14");
asm("ADDC r6, r8");
asm("ADD #1204, r5");
asm("AND.B #12311, r6");
asm("ADDC r15, r4");
asm("ADDC.B r8, r11");
asm("AND.B r14, r14");
asm("AND r13, r14");
asm("ADDC r13, r10");
asm("AND #-14290, r6");
asm("AND.B #3940, r11");
asm("AND.B r10, r7");
asm("ADD.B r7, r9");
asm("ADD #22513, r12");
asm("ADD.B r9, r15");
asm("ADDC.B r6, r13");
asm("ADD.B r8, r13");
asm("ADDC r6, r4");
asm("ADDC r6, r5");
asm("ADD r4, r13");
asm("AND r11, r12");
asm("ADD #-24552, r9");
asm("ADDC.B #-4703, r8");
asm("AND r7, r10");
asm("ADD r13, r15");
asm("ADD.B #-4393, r10");
asm("ADDC r6, r15");
asm("ADD.B r6, r11");
asm("AND.B #4989, r13");
asm("AND #-1418, r13");
asm("ADD r5, r6");
asm("ADDC r9, r6");
asm("AND #-25223, r9");
asm("ADDC.B r10, r10");
asm("ADD.B #4695, r12");
asm("ADDC.B r11, r11");
asm("ADD.B #-7188, r6");
asm("ADD.B r6, r4");
asm("ADDC #12180, r15");
asm("ADDC #-820, r4");
asm("ADDC.B #-25777, r7");
asm("ADD r14, r11");
asm("AND r8, r7");
asm("ADDC #29984, r6");
asm("ADD r10, r10");
asm("ADD #15422, r4");
asm("AND r12, r13");
asm("ADD #6704, r8");
asm("AND r15, r5");
asm("ADDC #-16203, r13");
asm("ADDC.B r13, r9");
asm("AND #-8422, r7");
asm("AND #24981, r7");
asm("ADDC.B r7, r8");
asm("AND.B r4, r7");
asm("ADD.B r10, r4");
asm("ADDC r9, r13");
asm("AND.B #-15090, r9");
asm("ADDC.B r15, r7");
asm("ADD r6, r7");
asm("ADDC r8, r11");
asm("ADDC #5445, r9");
asm("ADD.B r11, r5");
asm("AND.B r12, r7");
asm("ADDC #-23442, r4");
asm("ADD r14, r15");
asm("ADDC.B #14544, r8");
asm("ADDC #25271, r9");
asm("AND.B r9, r14");
asm("AND.B #11684, r6");
asm("AND r14, r7");
asm("ADD.B r8, r10");
asm("ADDC r14, r5");
asm("AND r5, r11");
asm("AND r6, r7");
asm("ADD r11, r10");
asm("ADDC r14, r13");
asm("ADD.B r6, r6");
asm("AND r11, r4");
asm("ADDC r13, r4");
asm("AND.B r6, r10");
asm("AND r13, r7");
asm("ADD r10, r7");
asm("AND.B #5285, r8");
asm("AND.B r9, r11");
asm("ADDC #21341, r9");
asm("ADDC r14, r8");
asm("ADD.B #7217, r15");
asm("ADD #-18631, r9");
asm("ADDC r11, r4");
asm("ADD #17060, r4");
asm("AND.B r13, r5");
asm("AND r7, r6");
asm("AND.B #14095, r12");
asm("ADD.B #8277, r6");
asm("ADD.B #14655, r12");
asm("ADD.B #4419, r4");
asm("ADDC r8, r13");
asm("ADDC r8, r12");
asm("AND #2393, r14");
asm("AND #-11063, r5");
asm("ADD r5, r4");
asm("ADD.B #21736, r4");
asm("ADDC r6, r12");
asm("ADD.B r12, r6");
asm("AND r11, r5");
asm("ADDC.B #-1598, r12");
asm("ADDC.B #-28276, r15");
asm("ADD.B #24903, r12");
asm("ADD.B #32765, r7");
asm("ADDC.B r8, r5");
asm("ADD.B r15, r12");
asm("AND.B r15, r15");
asm("ADDC.B r8, r15");
asm("AND.B #24679, r6");
asm("ADDC.B r10, r13");
asm("AND.B r8, r10");
asm("ADDC.B #-22261, r4");
asm("ADDC.B r5, r10");
asm("AND.B r7, r7");
asm("ADD r14, r9");
asm("ADDC.B #19457, r12");
asm("ADDC #-16367, r5");
asm("ADDC r10, r7");
asm("ADD.B r4, r8");
asm("ADD.B #-9563, r12");
asm("ADDC #-31638, r10");
asm("ADDC.B #10767, r6");
asm("ADDC.B r13, r15");
asm("AND.B #19855, r10");
asm("AND.B #27632, r10");
asm("ADDC r7, r15");
asm("ADD #12241, r12");
asm("ADD.B #-8208, r8");
asm("ADD.B #-4362, r15");
asm("AND.B #26491, r8");
asm("AND r13, r14");
asm("ADD r8, r5");
asm("ADD r11, r9");
asm("AND r12, r10");
asm("ADDC.B #-22427, r5");
asm("ADDC r15, r10");
asm("AND r5, r15");
asm("AND #-26372, r4");
asm("ADDC r13, r6");
asm("AND.B #16779, r8");
asm("ADDC.B r4, r9");
asm("AND.B r12, r6");
asm("ADD #-3949, r10");
asm("ADD #18339, r8");
asm("ADDC.B #21803, r15");
asm("ADD r7, r12");
asm("ADDC.B #28972, r11");
asm("ADDC.B #-12004, r11");
asm("ADD.B #31889, r9");
asm("ADDC r6, r10");
asm("ADD r11, r11");
asm("ADD.B #31266, r11");
asm("ADDC.B r10, r13");
asm("ADDC.B r5, r15");
asm("AND #25936, r10");
asm("AND r9, r13");
asm("ADD.B r7, r4");
asm("ADDC.B #-16115, r10");
asm("AND r12, r7");
asm("ADDC #9288, r14");
asm("ADD.B #-13664, r11");
asm("ADD r6, r4");
asm("ADDC r10, r6");
asm("AND.B r8, r7");
asm("ADD.B #-29885, r8");
asm("ADDC #25728, r15");
asm("ADD #-32754, r15");
asm("AND.B r10, r13");
asm("AND.B #24474, r5");
asm("AND.B r5, r8");
asm("ADDC #20856, r6");
asm("AND r11, r13");
asm("ADD r4, r9");
asm("ADDC.B r13, r12");
asm("ADD r8, r14");
asm("AND.B r6, r7");
asm("ADD.B #-204, r13");
asm("ADD #-675, r4");
asm("ADDC.B r5, r10");
asm("AND r7, r7");
asm("AND.B r10, r14");
asm("AND.B #7618, r7");
asm("ADD.B #14415, r12");
asm("ADDC.B #11037, r7");
asm("ADDC #20627, r8");
asm("ADD.B #6519, r9");
asm("ADD.B r4, r8");
asm("AND.B r9, r9");
asm("ADDC r7, r9");
asm("ADD.B #6346, r4");
asm("AND.B r11, r6");
asm("ADD #15449, r7");
asm("ADDC #-6109, r9");
asm("ADDC.B #-3533, r11");
asm("ADDC r13, r8");
asm("ADD r7, r15");
asm("ADDC #29333, r4");
asm("ADD.B #-9309, r14");
asm("AND.B #-30572, r11");
asm("AND r13, r14");
asm("ADDC #11584, r15");
asm("ADD.B #-18740, r13");
asm("ADD.B r12, r6");
asm("AND.B #-27870, r7");
asm("AND.B #17223, r8");
asm("AND.B #-5573, r13");
asm("ADDC r15, r13");
asm("AND.B r10, r6");
asm("ADD r8, r6");
asm("ADDC.B #-8877, r6");
asm("ADDC.B #-31833, r12");
asm("ADDC r4, r9");
asm("ADD r15, r4");
asm("AND.B r6, r14");
asm("ADDC #-15289, r8");
asm("ADDC.B #-9099, r5");
asm("ADD #-7954, r9");
asm("ADD #-30326, r15");
asm("AND #-2074, r7");
asm("ADDC #14365, r10");
asm("ADDC.B r15, r12");
asm("ADD.B #20900, r10");
asm("ADD.B r8, r6");
asm("ADD.B r5, r8");
asm("ADD.B r5, r4");
asm("ADD #-23661, r12");
asm("ADDC.B #21889, r9");
asm("ADDC.B r11, r5");
asm("ADD.B r4, r13");
asm("AND r15, r8");
asm("ADDC.B #-9541, r5");
asm("ADDC r7, r7");
asm("AND r6, r6");
asm("AND #-24011, r6");
asm("ADD.B r10, r4");
asm("ADDC #6037, r13");
asm("AND.B r14, r7");
asm("ADDC r14, r4");
asm("ADD.B r8, r12");
asm("AND r14, r7");
asm("ADDC #-30899, r11");
asm("ADDC r11, r12");
asm("ADDC.B r4, r14");
asm("AND #6504, r5");
asm("ADDC #-22429, r15");
asm("AND.B #15693, r13");
asm("ADD.B r10, r5");
asm("ADDC.B r12, r9");
asm("ADD #25003, r13");
asm("AND.B #-32445, r12");
asm("AND #6880, r11");
asm("AND #6569, r9");
asm("AND.B r10, r4");
asm("AND r7, r8");
asm("ADDC r6, r6");
asm("ADDC #29659, r5");
asm("ADDC #-30976, r12");
asm("ADD r10, r8");
asm("ADD r14, r8");
asm("AND.B #-3852, r5");
asm("AND #27152, r14");
asm("ADDC r10, r11");
asm("AND #-23583, r10");
asm("ADDC r13, r10");
asm("AND #20703, r15");
asm("ADD #-5473, r10");
asm("AND.B #-6741, r15");
asm("ADD #8594, r5");
asm("AND #-29895, r15");
asm("AND r5, r9");
asm("AND.B #27187, r5");
asm("ADDC r10, r5");
asm("AND r5, r7");
asm("AND.B r8, r6");
asm("ADDC r12, r9");
asm("ADD.B r14, r10");
asm("ADDC.B r9, r14");
asm("AND r10, r13");
asm("ADD #1642, r5");
asm("AND.B #21714, r6");
asm("ADDC #24803, r11");
asm("ADD.B #-6408, r13");
asm("ADDC #-18434, r10");
asm("ADDC.B #-14797, r8");
asm("AND.B #25000, r6");
asm("ADDC r12, r8");
asm("ADD #27686, r15");
asm("ADDC #-20452, r10");
asm("ADDC.B #11566, r10");
asm("ADDC #27291, r14");
asm("ADDC.B r5, r5");
asm("ADDC r12, r14");
asm("ADD #1564, r10");
asm("ADD #23956, r15");
asm("ADD #29314, r8");
asm("ADD #8069, r6");
asm("ADDC r7, r9");
asm("ADDC.B r8, r11");
asm("ADD #17355, r9");
asm("AND #2712, r8");
asm("ADD.B r5, r9");
asm("AND #15901, r13");
asm("ADDC r15, r11");
asm("ADD.B r11, r13");
asm("ADD.B #-24397, r7");
asm("ADD.B #27745, r4");
asm("ADDC.B r11, r15");
asm("ADD #-21324, r4");
asm("AND.B r5, r11");
asm("ADDC r5, r10");
asm("AND #-26270, r14");
asm("ADDC.B #27168, r14");
asm("ADDC r12, r9");
asm("AND.B r7, r10");
asm("ADD.B r12, r5");
asm("AND #6896, r6");
asm("ADD #26995, r7");
asm("ADDC.B #29268, r7");
asm("ADDC #-21844, r12");
asm("ADDC.B #-14983, r4");
asm("AND r10, r10");
asm("AND r8, r10");
asm("ADDC #-1769, r5");
asm("ADDC #4502, r5");
asm("ADD r9, r12");
asm("ADD #-11648, r9");
asm("AND r15, r6");
asm("AND r13, r14");
asm("ADDC.B #-10670, r12");
asm("ADDC.B r11, r9");
asm("ADDC r11, r13");
asm("AND #22902, r5");
asm("ADD.B r4, r14");
asm("ADDC.B #10974, r10");
asm("ADDC #-26366, r13");
asm("ADD r9, r7");
asm("AND.B #21479, r10");
asm("AND r11, r7");
asm("AND r6, r12");
asm("ADDC r13, r12");
asm("ADD.B r10, r11");
asm("ADD.B #-24838, r5");
asm("AND #1071, r14");
asm("ADD r4, r12");
asm("ADDC r5, r14");
asm("ADD.B r10, r11");
asm("ADD.B r8, r13");
asm("AND.B #22641, r4");
asm("ADD r12, r10");
asm("ADDC.B r7, r15");
asm("ADD.B #29611, r5");
asm("AND.B r5, r14");
asm("ADD.B #15028, r15");
asm("ADD.B #-22575, r4");
asm("ADDC #7324, r15");
asm("ADDC r8, r4");
asm("ADDC #27736, r14");
asm("ADDC #-31546, r9");
asm("AND #-2673, r12");
asm("ADD.B r10, r7");
asm("AND r13, r4");
asm("AND r14, r10");
asm("ADD.B r6, r10");
asm("ADDC r5, r4");
asm("AND #-5750, r14");
asm("ADDC.B r13, r7");
asm("ADD r8, r8");
asm("ADD #-26646, r12");
asm("ADDC #-17668, r12");
asm("ADD.B #20707, r11");
asm("ADD #23890, r4");
asm("AND.B r13, r7");
asm("ADDC.B #10425, r10");
asm("ADD.B r13, r4");
asm("AND #16146, r12");
asm("ADDC.B r9, r14");
asm("AND.B r15, r13");
asm("AND #-20360, r14");
asm("ADD r5, r6");
asm("ADD r4, r14");
asm("AND.B r6, r15");
asm("ADD.B r13, r7");
asm("ADD.B #-9737, r5");
asm("ADDC #-31646, r10");
asm("ADDC #-22360, r10");
asm("ADDC #16053, r5");
asm("AND r11, r14");
asm("ADD.B r15, r6");
asm("ADD.B r8, r4");
asm("AND.B r6, r13");
asm("ADDC #-31849, r4");
asm("ADD r8, r5");
asm("ADDC.B #5646, r4");
asm("ADDC.B #5919, r4");
asm("ADD.B #-15287, r14");
asm("ADDC.B #16050, r12");
asm("ADDC r13, r11");
asm("ADD r9, r13");
asm("AND.B r4, r12");
asm("ADD.B #-25911, r8");
asm("ADD.B #-23581, r13");
asm("ADD #-25814, r9");
asm("ADD.B r8, r5");
asm("ADDC r13, r15");
asm("ADD.B r9, r7");
asm("ADD.B #7359, r12");
asm("AND.B r10, r5");
asm("ADD.B #30620, r14");
asm("AND r7, r15");
asm("ADDC.B #15765, r4");
asm("ADD.B #22567, r13");
asm("AND.B r12, r14");
asm("ADD #22539, r8");
asm("ADDC.B r13, r5");
asm("ADD.B #17484, r6");
asm("ADD #-31579, r15");
asm("ADD #16518, r5");
asm("ADD #-3531, r13");
asm("AND r5, r6");
asm("AND.B #25652, r5");
asm("ADD.B r11, r6");
asm("AND r13, r6");
asm("ADDC.B #30441, r10");
asm("ADD #-27538, r13");
asm("ADD r8, r7");
asm("ADD r10, r6");
asm("ADDC r12, r8");
asm("ADD #18713, r12");
asm("AND r7, r13");
asm("ADD.B r4, r6");
asm("ADD #9957, r10");
asm("AND r11, r12");
asm("AND r13, r9");
asm("ADDC #-10723, r8");
asm("ADDC.B #-12492, r15");
asm("AND #7620, r9");
asm("AND #6013, r9");
asm("AND r9, r8");
asm("ADD r12, r11");
asm("ADD r7, r5");
asm("AND.B #-14652, r6");
asm("ADDC r7, r9");
asm("AND #-1007, r11");
asm("ADD.B #12881, r13");
asm("AND.B #-16206, r5");
asm("AND #22630, r4");
asm("ADD r8, r9");
asm("AND.B #5370, r10");
asm("AND.B r11, r9");
asm("ADDC #-2917, r4");
asm("ADD.B r11, r12");
asm("ADDC.B #25772, r9");
asm("ADDC r5, r4");
asm("AND #6508, r11");
asm("ADD.B #-18656, r13");
asm("AND r8, r13");
asm("ADD r12, r7");
asm("ADD #-29751, r5");
asm("AND #-29274, r12");
asm("ADD.B #22242, r9");
asm("ADDC r15, r6");
asm("AND r10, r6");
asm("AND.B #-1694, r13");
asm("AND.B #-26505, r9");
asm("ADD r5, r8");
asm("ADD.B #-1800, r6");
asm("ADDC r12, r10");
asm("AND.B #-25188, r13");
asm("ADD r14, r5");
asm("ADD.B #4881, r7");
asm("ADD r9, r12");
        asm("MOV #-12285, r4");
asm("MOV #-21802, r5");
asm("MOV #-32766, r6");
asm("MOV #-3449, r7");
asm("MOV #-12224, r8");
asm("MOV #26410, r9");
asm("MOV #-8319, r10");
asm("MOV #24465, r11");
asm("MOV #-12924, r12");
asm("MOV #18608, r13");
asm("MOV #-9772, r14");
asm("MOV #7295, r15");
                asm("ADD #4, r4"); // clear flags
                toggleTask(LMM1_TAG);
                asm("nop");
                asm("nop");
                asm("nop");
                asm("nop");
                asm("nop");
                asm("nop");
asm("CMP #7126, r13");
asm("MOV.B #649, r4");
asm("DECD r15");
asm("INC.B r15");
asm("CLR r9");
asm("ADDC r5, r10");
asm("BIS.B r8, r6");
asm("ADC r8");
asm("SETZ");
asm("CLRN");
asm("BIS.B #-19135, r11");
asm("INC r14");
asm("BIT.B #324, r14");
asm("INCD.B r6");
asm("SETZ");
asm("INC r9");
asm("INCD.B r11");
asm("CLRZ");
asm("CLRC");
asm("ADDC r4, r4");
asm("BIC.B #-25390, r12");
asm("DECD r4");
asm("SWPB.B r12");
asm("RLA.B r9");
asm("DECD.B r6");
asm("BIS #15071, r12");
asm("XOR.B r7, r15");
asm("DECD.B r4");
asm("INCD.B r14");
asm("CLR r13");
asm("SETZ");
asm("CLRZ");
asm("SUBC.B #-20341, r5");
asm("SETN");
asm("SBC r7");
asm("BIT.B #-9134, r6");
asm("SETZ");
asm("SXT.B r12");
asm("INCD r4");
asm("XOR #-22663, r7");
asm("CMP.B #-15903, r10");
asm("INCD r7");
asm("RLA r7");
asm("SXT r12");
asm("SUB r9, r6");
asm("CLRN");
asm("SUB r15, r5");
asm("DADD.B r6, r11");
asm("RLC.B r14");
asm("NOP");
asm("CLRZ");
asm("INV r13");
asm("SXT r8");
asm("CLR r13");
asm("DEC.B r7");
asm("SETC");
asm("BIC.B #26650, r14");
asm("SUBC #-6081, r11");
asm("DECD.B r15");
asm("BIS #-904, r12");
asm("XOR #19624, r13");
asm("NOP");
asm("SUB.B #-12048, r5");
asm("DADD.B r14, r15");
asm("RRA.B r11");
asm("SETN");
asm("BIT.B r6, r5");
asm("XOR #21535, r15");
asm("DECD.B r4");
asm("INC r13");
asm("RRC r9");
asm("RLA.B r15");
asm("DADC.B r14");
asm("SETZ");
asm("SXT r11");
asm("INC.B r10");
asm("MOV.B r12, r14");
asm("RRA.B r9");
asm("MOV.B #9902, r8");
asm("AND.B r9, r10");
asm("RLA r10");
asm("SUBC.B #4887, r12");
asm("RLA r4");
asm("DECD.B r10");
asm("DECD.B r10");
asm("RLC.B r13");
asm("SUBC r14, r9");
asm("ADD.B #-9255, r8");
asm("DEC r6");
asm("ADC r7");
asm("SETN");
asm("CLRN");
asm("SBC r12");
asm("CLRN");
asm("AND.B r14, r4");
asm("CLRZ");
asm("RRA.B r4");
asm("INC r5");
asm("SETN");
asm("CLRC");
asm("SXT.B r8");
asm("CLR.B r13");
asm("XOR #26131, r12");
asm("NOP");
asm("SWPB r10");
asm("DADD r4, r10");
asm("DECD r6");
asm("RRC.B r14");
asm("CLRN");
asm("CLR r12");
asm("BIC r8, r5");
asm("SUB r11, r4");
asm("SETC");
asm("DADC r9");
asm("INC r9");
asm("INCD.B r8");
asm("SETZ");
asm("INC.B r9");
asm("NOP");
asm("SETZ");
asm("CLRC");
asm("ADDC.B r7, r4");
asm("NOP");
asm("ADDC.B #24594, r7");
asm("DEC r15");
asm("BIC #1079, r4");
asm("SETN");
asm("BIS.B r15, r14");
asm("XOR.B #-25524, r13");
asm("DADC.B r12");
asm("SETC");
asm("RRC.B r4");
asm("DADD.B #-2071, r11");
asm("RLC r10");
asm("MOV r5, r11");
asm("SUB.B r6, r15");
asm("DADC.B r15");
asm("SETN");
asm("RLA r5");
asm("DADD #23194, r8");
asm("SETZ");
asm("CLRZ");
asm("BIT.B #21883, r10");
asm("SUBC r14, r6");
asm("NOP");
asm("DADC.B r15");
asm("INV r7");
asm("RLC r4");
asm("SWPB.B r15");
asm("ADC r6");
asm("AND.B r8, r8");
asm("BIT #2134, r14");
asm("INV.B r7");
asm("SETC");
asm("DECD r4");
asm("DECD r10");
asm("RRC r11");
asm("MOV r13, r8");
asm("DEC r11");
asm("CLRZ");
asm("TST r13");
asm("BIS.B #21950, r7");
asm("DADD.B r11, r12");
asm("MOV r9, r10");
asm("INV.B r6");
asm("CLRC");
asm("SUBC r8, r10");
asm("INCD r10");
asm("RLC r11");
asm("ADC.B r11");
asm("SETZ");
asm("RLA.B r6");
asm("BIC r11, r12");
asm("CLR r8");
asm("CMP.B #-22203, r7");
asm("SUB.B #-29577, r10");
asm("BIT #-7830, r13");
asm("RRA.B r13");
asm("SBC.B r14");
asm("RLC r10");
asm("NOP");
asm("BIC.B #-25820, r6");
asm("SETZ");
asm("AND.B r13, r13");
asm("BIC.B #20028, r14");
asm("DEC r4");
asm("ADD r7, r6");
asm("DADD #5570, r13");
asm("INC.B r12");
asm("SWPB.B r10");
asm("BIC #-7900, r14");
asm("RRC.B r14");
asm("CLRN");
asm("BIT #-8748, r15");
asm("CLRN");
asm("DEC.B r11");
asm("SETC");
asm("RRA r10");
asm("BIC r10, r10");
asm("DECD r13");
asm("INCD r15");
asm("DEC.B r4");
asm("MOV.B r15, r5");
asm("SETC");
asm("MOV.B r4, r15");
asm("SWPB r14");
asm("NOP");
asm("SETZ");
asm("CLRZ");
asm("CLR.B r6");
asm("BIC #-20789, r6");
asm("INV.B r15");
asm("TST r6");
asm("MOV #-4227, r10");
asm("NOP");
asm("CMP.B #11846, r4");
asm("CLRZ");
asm("BIS.B r9, r7");
asm("AND.B r11, r5");
asm("RLC r15");
asm("SXT r12");
asm("INV r8");
asm("DECD.B r11");
asm("XOR r7, r8");
asm("TST.B r12");
asm("SUB #-15383, r6");
asm("TST.B r5");
asm("SUBC.B #-24245, r7");
asm("RLA r7");
asm("CLRZ");
asm("BIS.B r6, r6");
asm("SETN");
asm("DADC r7");
asm("SETZ");
asm("CLRZ");
asm("AND r9, r6");
asm("MOV.B r7, r11");
asm("SWPB.B r12");
asm("RLA.B r12");
asm("RRC r4");
asm("SUBC.B r15, r11");
asm("ADDC #-19127, r8");
asm("ADD.B r4, r11");
asm("SWPB r11");
asm("ADDC #18347, r4");
asm("CLRZ");
asm("RLC r7");
asm("CMP.B r14, r6");
asm("BIT.B #-13671, r6");
asm("CLR.B r10");
asm("RRA r10");
asm("RRC.B r11");
asm("SETN");
asm("AND.B #-23210, r10");
asm("INCD r11");
asm("TST r9");
asm("CLRZ");
asm("SETN");
asm("BIT.B #-7428, r4");
asm("DADC.B r10");
asm("ADDC.B #-31054, r9");
asm("RRA r10");
asm("SUBC.B r14, r8");
asm("CLRC");
asm("CLRC");
asm("SUB.B #-685, r13");
asm("TST.B r15");
asm("MOV.B #-32043, r4");
asm("CLR r11");
asm("BIT #27304, r8");
asm("BIS r14, r14");
asm("SWPB.B r7");
asm("SETN");
asm("BIT #-9088, r7");
asm("XOR.B r9, r10");
asm("DADD.B r5, r4");
asm("CLR.B r5");
asm("SETZ");
asm("SXT.B r15");
asm("RLC.B r15");
asm("RLC r14");
asm("TST r9");
asm("INC.B r4");
asm("AND.B r14, r12");
asm("AND.B r12, r10");
asm("SETZ");
asm("XOR.B #-28574, r12");
asm("DEC.B r15");
asm("DADC.B r12");
asm("RLC.B r11");
asm("NOP");
asm("XOR.B r8, r13");
asm("SBC.B r12");
asm("SETC");
asm("RLA r14");
asm("SBC.B r11");
asm("DADD r5, r4");
asm("NOP");
asm("SETZ");
asm("RLC.B r12");
asm("ADC r6");
asm("SBC.B r11");
asm("CLRC");
asm("SWPB.B r6");
asm("ADD r15, r11");
asm("AND #25355, r10");
asm("XOR.B r7, r10");
asm("XOR.B r7, r7");
asm("SXT r14");
asm("SWPB.B r11");
asm("CLRN");
asm("SETZ");
asm("INCD.B r15");
asm("RLC.B r9");
asm("TST.B r5");
asm("CMP.B #17495, r15");
asm("SUB.B r11, r14");
asm("SUB.B #-15479, r5");
asm("XOR #-18199, r10");
asm("SUB r6, r15");
asm("CLR r15");
asm("CLRC");
asm("CLRZ");
asm("RRA r13");
asm("CMP #20738, r11");
asm("DEC r12");
asm("ADC.B r15");
asm("SETZ");
asm("RRC.B r15");
asm("INCD.B r7");
asm("DADC.B r4");
asm("INCD r7");
asm("BIT.B #-11445, r14");
asm("MOV r11, r6");
asm("TST r10");
asm("INC r10");
asm("AND.B #-19314, r12");
asm("INC r12");
asm("MOV #-11296, r7");
asm("SUBC #6249, r14");
asm("ADD r11, r7");
asm("INV.B r4");
asm("BIS.B r12, r13");
asm("DEC r8");
asm("DADD.B r11, r15");
asm("TST.B r6");
asm("SBC.B r11");
asm("INCD r7");
asm("SETZ");
asm("SBC.B r4");
asm("CLR.B r7");
asm("SWPB.B r11");
asm("RLC.B r5");
asm("ADD.B r14, r15");
asm("BIT #12956, r6");
asm("BIT.B r11, r14");
asm("INV.B r7");
asm("ADDC.B r11, r12");
asm("RLA r12");
asm("ADDC.B r4, r8");
asm("DECD r10");
asm("NOP");
asm("ADC.B r7");
asm("CLRC");
asm("NOP");
asm("SXT.B r13");
asm("INCD.B r8");
asm("RRC r12");
asm("SETN");
asm("ADC.B r13");
asm("TST.B r4");
asm("RLA r5");
asm("NOP");
asm("CLRN");
asm("RLA r11");
asm("SUBC.B #16392, r14");
asm("CLRC");
asm("NOP");
asm("CLRN");
asm("AND r9, r9");
asm("CMP #15675, r8");
asm("BIT #-13275, r7");
asm("CLRC");
asm("BIS.B #26809, r15");
asm("RLA.B r10");
asm("DADD.B r12, r8");
asm("CLRN");
asm("RLC r14");
asm("DADD.B r7, r5");
asm("CLR.B r12");
asm("ADDC #-586, r14");
asm("CLRC");
asm("SETZ");
asm("XOR.B r13, r6");
asm("AND #-6134, r12");
asm("ADDC.B r11, r11");
asm("SXT r9");
asm("ADDC.B r5, r13");
asm("RLA.B r12");
asm("BIT.B #-12366, r4");
asm("CMP r14, r15");
asm("SUB r7, r10");
asm("ADC r11");
asm("NOP");
asm("MOV.B #-17493, r6");
asm("CMP.B #18659, r15");
asm("BIT.B r14, r8");
asm("ADDC r9, r13");
asm("CLRC");
asm("SETZ");
asm("CLRC");
asm("SBC.B r11");
asm("ADDC.B #19106, r7");
asm("SUBC.B r15, r8");
asm("CLRZ");
asm("SBC r8");
asm("RRA.B r4");
asm("INC.B r13");
asm("SXT.B r9");
asm("CMP r11, r6");
asm("CMP.B r9, r5");
asm("XOR.B r12, r9");
asm("DECD r13");
asm("BIT.B #2408, r13");
asm("AND #-23575, r11");
asm("AND r11, r8");
asm("SETZ");
asm("INCD r14");
asm("SETZ");
asm("XOR.B r14, r5");
asm("TST r12");
asm("RRC.B r4");
asm("CLRZ");
asm("XOR.B r4, r8");
asm("SETZ");
asm("RRA.B r13");
asm("SETN");
asm("SETC");
asm("INCD.B r12");
asm("BIS.B r14, r9");
asm("INV.B r11");
asm("XOR #23258, r8");
asm("RLC.B r4");
asm("DECD.B r15");
asm("INC r9");
asm("DADC.B r15");
asm("TST.B r5");
asm("AND r6, r13");
asm("DEC r11");
asm("ADDC.B #10729, r13");
asm("CLR r13");
asm("RLC r4");
asm("SETN");
asm("SETN");
asm("RRC r9");
asm("MOV #-18052, r12");
asm("SETN");
asm("RLC r11");
asm("ADC.B r9");
asm("RRC.B r4");
asm("TST r9");
asm("RLC.B r13");
asm("SUBC.B #19878, r10");
asm("SUB.B #4457, r6");
asm("CLRC");
asm("BIS.B #-8909, r10");
asm("SETC");
asm("TST.B r11");
asm("DADC.B r12");
asm("SETZ");
asm("INC r8");
asm("BIS.B #-10225, r6");
asm("DADC.B r13");
asm("DADC.B r7");
asm("INCD r13");
asm("RLA.B r14");
asm("CMP r13, r5");
asm("SETZ");
asm("BIS.B #16856, r4");
asm("CLR.B r14");
asm("SUB r7, r12");
asm("TST r9");
asm("MOV r7, r7");
asm("SETN");
asm("DADD #29718, r12");
asm("SUB #-20104, r8");
asm("CLR.B r15");
asm("SETC");
asm("SETC");
asm("SUBC.B #26052, r14");
asm("SWPB.B r4");
asm("DECD r12");
asm("CMP r6, r14");
asm("DADD r8, r5");
asm("XOR r6, r13");
asm("RRA r11");
asm("SBC r15");
asm("INC.B r8");
asm("INV.B r14");
asm("DADC.B r5");
asm("CLRN");
asm("RLC.B r7");
asm("SXT r12");
asm("BIC r10, r15");
asm("RRA r10");
asm("DEC.B r7");
asm("CLRZ");
asm("DEC.B r13");
asm("SXT.B r14");
asm("CLRN");
asm("SETC");
asm("SUBC #-1292, r6");
asm("INC.B r7");
asm("SXT r10");
asm("DECD r9");
asm("NOP");
asm("ADD r11, r7");
asm("ADDC r15, r9");
asm("CMP.B #9387, r5");
asm("ADC r14");
asm("ADC.B r7");
asm("XOR.B r15, r12");
asm("INV.B r7");
asm("ADD #-1271, r5");
asm("INCD r5");
asm("CLRZ");
asm("RRC r7");
asm("SWPB.B r11");
asm("ADDC #-6443, r4");
asm("CLRN");
asm("SETN");
asm("CLRN");
asm("INV.B r9");
asm("NOP");
asm("DEC r5");
asm("ADD.B #26762, r6");
asm("MOV #-25878, r14");
asm("BIT.B r15, r10");
asm("CLRN");
asm("CLRZ");
asm("RRA r12");
asm("SETN");
asm("DEC r10");
asm("ADC r6");
asm("AND #14780, r5");
asm("SBC.B r11");
asm("BIS #27164, r4");
asm("SBC r12");
asm("AND #-26013, r6");
asm("DADD.B r7, r5");
asm("CLRN");
asm("XOR.B #436, r4");
asm("ADD r4, r6");
asm("INC r11");
asm("INCD r7");
asm("RLA.B r9");
asm("CLRN");
asm("DECD.B r14");
asm("ADDC.B #-7124, r13");
asm("SUB.B #-4327, r9");
asm("DEC.B r13");
asm("RLA.B r15");
asm("AND r10, r11");
asm("CLRN");
asm("RRA r10");
asm("CLRN");
asm("RRC.B r13");
asm("RLC r14");
asm("SUB.B #-2691, r11");
asm("RLC r7");
asm("BIS.B r12, r6");
asm("BIC.B r12, r5");
asm("CLRC");
asm("SETC");
asm("SXT r5");
asm("SETN");
asm("NOP");
asm("SXT r14");
asm("SBC r15");
asm("RLA.B r14");
asm("ADD.B #4619, r15");
asm("RRC.B r11");
asm("XOR.B r13, r7");
asm("BIC #27078, r8");
asm("SETN");
asm("TST r6");
asm("CMP.B #20981, r8");
asm("RLC.B r7");
asm("ADDC.B r7, r5");
asm("CLRZ");
asm("ADDC.B #13021, r10");
asm("RLA.B r15");
asm("SUBC #10836, r7");
asm("BIT.B #-24426, r10");
asm("SETN");
asm("SUBC #30453, r14");
asm("DADD.B #10057, r14");
asm("CLR r13");
asm("BIC #4960, r12");
asm("DADD.B r6, r8");
asm("INC r12");
asm("INC.B r10");
asm("SUB.B #25461, r7");
asm("CLRN");
asm("CLRC");
asm("SUBC #15289, r12");
asm("CLRC");
asm("DADC r11");
asm("DADD #11675, r6");
asm("DEC.B r9");
asm("INV.B r8");
asm("RRC r8");
asm("SWPB r5");
asm("NOP");
asm("CLR.B r9");
asm("SUBC #-357, r15");
asm("RRC r13");
asm("MOV r8, r13");
asm("SXT r15");
asm("AND.B r4, r9");
asm("CMP #-24421, r11");
asm("DEC r7");
asm("SXT.B r4");
asm("XOR r10, r8");
asm("SBC r14");
asm("CLR r8");
asm("AND r4, r9");
asm("BIT r9, r6");
asm("AND r7, r10");
asm("ADDC #-1939, r5");
asm("NOP");
asm("CLRC");
asm("ADD.B r13, r7");
asm("SWPB r6");
asm("DADC r9");
asm("SWPB r12");
asm("ADD.B r11, r6");
asm("SETN");
asm("DADC.B r4");
asm("DADC r10");
asm("SBC r14");
asm("CLR r14");
asm("RLA.B r6");
asm("SUBC.B #28720, r9");
asm("RLA.B r10");
asm("SETZ");
asm("SUBC.B #-14038, r13");
asm("INCD.B r14");
asm("CLRZ");
asm("SETN");
asm("BIT.B #-3304, r15");
asm("RLA r5");
asm("DECD r13");
asm("CLR r4");
asm("MOV #20138, r11");
asm("NOP");
asm("INV r11");
asm("CLRC");
asm("CMP.B #2418, r6");
asm("AND r11, r4");
asm("SWPB.B r8");
asm("DEC.B r8");
asm("SUB r15, r6");
asm("CMP r4, r4");
asm("ADC.B r8");
asm("MOV.B r10, r9");
asm("BIC.B r4, r4");
asm("RRA r9");
asm("CLRN");
asm("SUBC r13, r14");
asm("DECD r15");
asm("SUBC r12, r5");
asm("CLRC");
asm("MOV #18934, r12");
asm("RRA.B r7");
asm("SUB r14, r13");
asm("INCD r15");
asm("INCD r15");
asm("ADC r8");
asm("CMP r9, r14");
asm("SBC r9");
asm("DADC r13");
asm("DADD.B #14882, r4");
asm("SUB r10, r12");
asm("CLRC");
asm("BIC r6, r12");
asm("INV r12");
asm("DEC r6");
asm("ADDC #4264, r12");
asm("INCD.B r4");
asm("DEC r9");
asm("SETN");
asm("MOV #-15564, r15");
asm("ADC.B r12");
asm("INC r4");
asm("ADD r13, r4");
asm("SBC.B r13");
asm("BIT.B r12, r6");
asm("RLA r12");
asm("SBC.B r8");
asm("TST.B r6");
asm("RRA.B r7");
asm("CLRN");
asm("SUBC #31947, r6");
asm("AND.B r13, r4");
asm("RLC r4");
asm("SXT r9");
asm("SETN");
asm("INV.B r4");
asm("SETN");
asm("TST.B r15");
asm("RLA r14");
asm("RRC r15");
asm("ADC r15");
asm("BIC.B #-21412, r12");
asm("BIC #31123, r5");
asm("INC r7");
asm("ADDC r9, r10");
asm("ADD.B r11, r7");
asm("BIS.B #24532, r6");
asm("SUBC r12, r4");
asm("DEC r8");
asm("SETC");
asm("CLRZ");
asm("CLRZ");
asm("SETZ");
asm("BIS r12, r15");
asm("INV r14");
asm("BIC r8, r8");
asm("INCD.B r9");
asm("RLC.B r4");
asm("SUBC r10, r11");
asm("AND #-20327, r13");
asm("CLR r15");
asm("SETZ");
asm("BIT.B r5, r7");
asm("DADD #6922, r8");
asm("SETC");
asm("DECD r4");
asm("RLA r10");
asm("RRA.B r5");
asm("INC r14");
asm("SETN");
asm("DADC.B r10");
asm("INV.B r13");
asm("TST.B r5");
asm("CLR r9");
asm("SETN");
asm("INV r8");
asm("INC r7");
asm("RRA r13");
asm("DECD r9");
asm("XOR.B #-9740, r6");
asm("SETC");
asm("SWPB.B r11");
asm("RRA.B r4");
asm("AND.B #25608, r5");
asm("AND #12946, r4");
asm("DECD r13");
asm("SETZ");
asm("CLRC");
asm("SETN");
asm("TST.B r8");
asm("INCD r9");
asm("SWPB.B r15");
asm("ADDC.B r10, r6");
asm("RLC r14");
asm("SWPB.B r5");
asm("SETC");
asm("DEC r9");
asm("BIC r4, r13");
asm("AND #1736, r14");
asm("CLR.B r4");
asm("CLRC");
asm("RRA r10");
asm("INCD r8");
asm("SWPB.B r10");
asm("BIC r11, r10");
asm("BIT #30439, r6");
asm("BIT r13, r8");
asm("ADDC r11, r6");
asm("BIC.B r9, r9");
asm("DADD.B #-8415, r12");
asm("INC r13");
asm("SBC r15");
asm("ADDC.B #3687, r4");
asm("AND.B #11753, r10");
asm("SXT.B r8");
asm("DEC r13");
asm("DEC r7");
asm("BIS r6, r7");
asm("MOV r10, r5");
asm("ADC r5");
asm("SBC.B r13");
asm("MOV.B #-6532, r9");
asm("CLRC");
asm("SXT.B r4");
asm("NOP");
asm("SUBC r4, r9");
asm("ADDC.B r8, r14");
asm("SBC r6");
asm("DECD r7");
asm("RLA.B r5");
asm("ADDC.B #20210, r15");
asm("DECD r8");
asm("CLRC");
asm("CLRZ");
asm("SBC r9");
asm("SUB.B r13, r12");
asm("ADD.B r8, r15");
asm("SBC r4");
asm("SETN");
asm("BIS r15, r12");
asm("SWPB r11");
asm("RLA.B r13");
asm("SUBC.B #12525, r5");
asm("INV.B r13");
asm("NOP");
asm("TST.B r5");
asm("AND #11361, r13");
asm("XOR r9, r7");
asm("DECD.B r13");
asm("BIS.B r9, r7");
asm("DECD.B r12");
asm("SUBC.B #21948, r6");
asm("SETN");
asm("TST.B r13");
asm("SETZ");
asm("BIC.B #21562, r7");
asm("BIT #-14355, r7");
asm("RRA r13");
asm("SUBC.B #-29469, r8");
asm("INV.B r5");
asm("SBC.B r4");
asm("INV.B r10");
asm("CLRN");
asm("ADC.B r11");
asm("SETZ");
asm("CLR r10");
asm("DECD.B r14");
asm("SBC r9");
asm("RRC r14");
asm("BIS.B #-220, r10");
asm("BIC r9, r13");
asm("SXT r7");
asm("BIT #-22177, r8");
asm("CLRZ");
asm("SBC r8");
asm("INC r14");
asm("SXT.B r7");
asm("RLC.B r15");
asm("CLRN");
asm("DEC r13");
asm("SETN");
asm("DECD r10");
asm("SUBC.B #325, r13");
asm("TST r13");
asm("CLRZ");
asm("INV.B r13");
asm("BIS r11, r11");
asm("RLC.B r11");
asm("CLRZ");
asm("DEC.B r13");
asm("ADC r7");
asm("CLR.B r7");
asm("DECD r12");
asm("DEC r13");
asm("INC r8");
asm("INC r10");
asm("CLRZ");
asm("RLA.B r9");
asm("DEC r4");
asm("DADD.B r10, r6");
asm("SETN");
asm("AND.B #-6711, r7");
asm("BIT #23444, r15");
asm("INC r10");
asm("SETZ");
asm("XOR.B #-28438, r7");
asm("RLA r13");
asm("INC.B r15");
asm("TST r12");
asm("CLRZ");
asm("DADD.B r10, r7");
asm("RRA.B r11");
asm("SETN");
asm("ADDC.B r9, r13");
asm("AND.B #13954, r4");
asm("RLA r10");
asm("ADDC.B #-18332, r10");
asm("RLA r14");
asm("BIC.B r9, r11");
asm("CMP.B r6, r8");
asm("ADC r14");
asm("SWPB r15");
asm("SETC");
asm("NOP");
asm("CLRC");
asm("SWPB.B r10");
asm("BIT.B r10, r8");
asm("INC r8");
asm("CLRC");
asm("MOV #-29737, r8");
asm("SUBC.B r4, r4");
asm("INV r8");
asm("RLA r15");
asm("SWPB r8");
asm("CMP #15313, r5");
asm("INC.B r12");
asm("BIC #-29755, r15");
asm("DEC.B r9");
asm("SUB.B r7, r9");
asm("INCD.B r10");
asm("SBC r14");
asm("DEC.B r8");
asm("RLA.B r8");
asm("SUB #-10559, r14");
asm("SWPB.B r10");
asm("MOV #-10751, r12");
asm("DECD r12");
asm("AND.B r15, r14");
asm("ADD.B #-5132, r6");
asm("CLRZ");
asm("CLR r5");
asm("INC.B r15");
asm("AND.B #-22515, r5");
asm("DADC r4");
asm("CMP r11, r12");
asm("ADDC #-32061, r6");
asm("NOP");
asm("BIT #29405, r11");
asm("SETZ");
asm("SBC.B r11");
asm("DECD.B r8");
asm("CLRZ");
asm("DADC r4");
asm("AND #11911, r8");
asm("DEC r13");
asm("ADDC #-13449, r6");
asm("RLC r9");
asm("CLRN");
asm("ADD.B #16992, r7");
asm("CMP r9, r5");
asm("DECD.B r12");
asm("INC r13");
asm("DEC.B r14");
asm("INCD r7");
asm("XOR.B #2074, r15");
asm("INCD.B r11");
asm("SUBC r13, r13");
asm("DECD.B r10");
asm("SETN");
asm("SETZ");
asm("CLR.B r7");
asm("ADC r4");
asm("DADD.B #23981, r4");
asm("INCD.B r14");
asm("SUB.B r9, r12");
asm("DADD #21731, r9");
asm("DADC.B r4");
asm("SUBC.B r13, r8");
asm("CMP.B #706, r5");
asm("ADC.B r12");
asm("XOR.B #7772, r11");
asm("CLRC");
asm("CMP r6, r7");
asm("CLRZ");
asm("DADC.B r5");
asm("RRC.B r8");
asm("CLR r13");
asm("RLC r14");
asm("RLC r11");
asm("RRA.B r8");
asm("RLA.B r12");
asm("SETZ");
asm("ADC r4");
asm("SWPB r8");
asm("RLC.B r5");
asm("NOP");
asm("SUBC r10, r9");
asm("SUB r11, r15");
asm("RRC.B r14");
asm("INV.B r13");
asm("TST r11");
asm("SETC");
asm("INV r9");
asm("BIC #-7772, r12");
asm("CMP.B #9433, r10");
asm("RLA.B r9");
asm("TST.B r12");
asm("SUB.B r13, r11");
asm("NOP");
asm("DECD r14");
asm("RLA r14");
asm("SUB.B #7552, r6");
asm("AND.B r15, r7");
asm("SETC");
asm("DADD.B r9, r9");
asm("BIS r13, r14");
asm("DADC r12");
asm("SWPB.B r7");
asm("INCD.B r14");
asm("SUBC r6, r6");
asm("TST.B r6");
asm("SBC.B r11");
asm("SETZ");
asm("DEC r4");
asm("TST.B r9");
asm("NOP");
asm("SXT.B r15");
asm("ADDC.B #-9127, r5");
asm("RLA.B r12");
asm("SUBC.B r11, r12");
asm("CLRC");
asm("INV r6");
asm("ADC.B r8");
asm("RLC.B r10");
asm("XOR r11, r9");
asm("SETN");
asm("CLRN");
asm("CLRN");
asm("CLR.B r12");
asm("BIS #-11537, r9");
asm("SETZ");
asm("CMP #-9592, r4");
asm("SETN");
asm("BIS.B r10, r14");
asm("ADC.B r7");
asm("DADC.B r14");
asm("DEC r7");
asm("CLRC");
asm("CMP r11, r9");
asm("DADD.B r11, r7");
asm("AND.B #-3070, r11");
asm("MOV r12, r11");
asm("SUB #11888, r12");
asm("RRC.B r5");
asm("MOV #-20962, r9");
asm("BIS r12, r13");
asm("SUBC r7, r6");
asm("SUB.B #6643, r10");
asm("ADDC.B #-13617, r9");
asm("BIC #-31693, r8");
asm("XOR.B #8312, r8");
asm("CLRN");
asm("BIC.B #-26425, r15");
asm("ADC.B r5");
asm("SETN");
asm("DADC.B r10");
asm("CLRN");
asm("DEC.B r13");
asm("DADD #-10823, r11");
asm("SETC");
asm("DADD.B #19706, r8");
asm("TST.B r15");
asm("DECD.B r5");
asm("SWPB.B r9");
asm("RRC r12");
asm("NOP");
asm("SUB.B r14, r15");
asm("INCD.B r10");
asm("AND r12, r13");
asm("NOP");
asm("SBC r10");
asm("TST.B r7");
asm("MOV #-29250, r4");
asm("NOP");
asm("RRA r7");
asm("CLRN");
asm("CLR r6");
asm("TST r11");
asm("INCD.B r4");
asm("INCD r9");
asm("ADDC.B r5, r10");
asm("DEC r11");
asm("TST r15");
asm("INCD.B r7");
asm("TST r5");
asm("INC r4");
asm("RRC.B r5");
asm("SUB.B r5, r14");
asm("TST r13");
asm("AND #32615, r11");
asm("SXT r11");
asm("TST r15");
asm("ADC r11");
asm("DADC.B r4");
asm("SBC r4");
asm("DEC r8");
asm("SUB.B r7, r15");
asm("SUB.B r13, r13");
asm("SUBC.B r4, r11");
asm("SBC.B r11");
asm("SXT r11");
asm("XOR r13, r9");
asm("BIC.B r11, r15");
asm("SETC");
asm("DADC r12");
asm("INC.B r5");
asm("XOR.B r12, r12");
asm("DADC.B r6");
asm("CLRZ");
asm("CLRN");
asm("INC.B r7");
asm("RLC.B r14");
asm("BIT.B r7, r7");
asm("BIC r15, r7");
asm("INV.B r9");
asm("AND r5, r5");
asm("CMP r13, r14");
asm("XOR r12, r11");
asm("NOP");
asm("CMP r8, r9");
asm("CLRC");
asm("BIT.B #31014, r12");
asm("DECD r13");
asm("MOV #-7074, r9");
asm("INC r9");
asm("NOP");
asm("SBC r13");
asm("CLRN");
asm("BIS.B r4, r10");
asm("TST r8");
asm("SETC");
asm("ADC r14");
asm("NOP");
asm("CLR.B r6");
asm("NOP");
asm("TST r10");
asm("NOP");
asm("CLRZ");
asm("INV r12");
asm("INV.B r5");
asm("BIC.B r6, r4");
asm("DEC.B r9");
asm("RLA.B r8");
asm("RLA r8");
asm("SUBC r6, r5");
asm("SWPB.B r6");
asm("DEC r7");
asm("RRA.B r6");
asm("INCD r11");
asm("MOV r12, r7");
asm("INCD r10");
asm("CLR.B r9");
asm("RLA.B r12");
asm("DECD r10");
asm("XOR r5, r10");
asm("RRC.B r7");
asm("SWPB.B r14");
asm("MOV.B r7, r12");
asm("CLRZ");
asm("RLA.B r9");
asm("RLA.B r7");
asm("INC.B r14");
asm("ADDC #-17953, r10");
asm("CLRC");
asm("SETC");
asm("SETZ");
asm("INCD r14");
asm("INC r15");
asm("ADC.B r13");
asm("ADDC.B r6, r15");
asm("SETZ");
asm("CLRN");
asm("BIT #-7386, r6");
asm("INV r13");
asm("CMP.B #-29060, r15");
asm("SWPB.B r12");
asm("SETZ");
asm("AND.B #-28061, r9");
asm("XOR #-10913, r11");
asm("SWPB.B r4");
asm("RLA.B r4");
asm("INC r5");
asm("RRA.B r13");
asm("SBC.B r5");
asm("CLRN");
asm("BIC #5394, r11");
asm("SBC.B r6");
asm("ADDC #-10909, r10");
asm("NOP");
asm("BIT.B #-23316, r11");
asm("SUBC.B #2054, r7");
asm("AND r15, r10");
asm("RLC.B r6");
asm("SETC");
asm("DEC.B r13");
asm("SETZ");
asm("SWPB.B r5");
asm("DADC.B r11");
asm("SUBC #-29088, r11");
asm("INC.B r15");
asm("RRA.B r14");
asm("CMP #-14384, r14");
asm("BIC #-862, r11");
asm("SETC");
asm("MOV.B r4, r5");
asm("INCD r5");
asm("BIS.B #6092, r8");
asm("AND #10107, r15");
asm("INCD r11");
asm("ADC.B r11");
asm("SWPB r7");
asm("NOP");
asm("BIC r6, r9");
asm("CMP r7, r14");
asm("SBC.B r7");
asm("RLA r12");
asm("NOP");
asm("XOR r15, r6");
asm("SETN");
asm("RRA.B r13");
asm("SXT r5");
asm("SBC r15");
asm("RLC r5");
asm("SUB.B r15, r15");
asm("SWPB r8");
asm("RLC.B r11");
asm("CLRC");
asm("BIT #4045, r7");
asm("INCD.B r10");
asm("RLC.B r4");
asm("CLRN");
asm("CLRC");
asm("CLRC");
asm("SETC");
asm("DECD.B r11");
asm("ADD.B #22947, r11");
asm("RRC.B r6");
asm("DADD.B #15665, r15");
asm("CMP #-30247, r12");
asm("SETN");
asm("SETN");
asm("SBC.B r4");
asm("SWPB r11");
asm("ADD.B r13, r4");
asm("DEC r8");
asm("INV.B r7");
asm("NOP");
asm("ADDC.B #15267, r5");
asm("BIC.B #-22175, r13");
asm("SUB r8, r5");
asm("CMP.B #12338, r11");
asm("INCD r9");
asm("RLA.B r13");
asm("DEC r14");
asm("RLA.B r12");
asm("MOV #4652, r6");
asm("XOR.B #-6021, r5");
asm("SETC");
asm("RLC r12");
asm("DADD.B r12, r5");
asm("MOV.B r11, r7");
asm("MOV.B #29240, r5");
asm("BIT.B r6, r13");
asm("RRA.B r9");
asm("RRA r11");
asm("NOP");
asm("DECD.B r15");
asm("SETN");
asm("NOP");
asm("ADD #-14100, r7");
asm("SUBC.B r11, r15");
asm("SWPB r10");
asm("DECD.B r12");
asm("RLA.B r12");
asm("CLRZ");
asm("XOR.B r10, r14");
asm("INC r15");
asm("RRA.B r11");
asm("RRA.B r4");
asm("CLR r10");
asm("CLRZ");
asm("NOP");
asm("ADD.B #812, r7");
asm("CLRZ");
asm("BIT.B #-21681, r5");
asm("RLC.B r13");
asm("ADD r9, r5");
asm("ADC.B r9");
asm("RRA r9");
asm("RRC.B r11");
asm("SXT r7");
asm("RRA.B r10");
asm("SWPB.B r8");
asm("SETC");
asm("INCD.B r13");
asm("NOP");
asm("CMP r12, r7");
asm("XOR.B r8, r13");
asm("RRC r8");
asm("CLRC");
asm("INC.B r4");
asm("ADD #23757, r9");
asm("DEC.B r12");
asm("RLA.B r11");
asm("TST.B r12");
asm("NOP");
asm("SETZ");
asm("INCD.B r11");
asm("MOV.B r9, r7");
asm("DADD.B r6, r11");
asm("SUBC r11, r8");
asm("TST.B r15");
asm("SBC.B r11");
asm("NOP");
asm("CLRC");
asm("ADDC.B r8, r8");
asm("RLA.B r10");
asm("RRA.B r9");
asm("BIS r5, r11");
asm("TST r12");
asm("BIT.B r9, r11");
asm("DADC.B r10");
asm("CLRC");
asm("SETZ");
asm("NOP");
asm("CLR r8");
asm("SUB.B r9, r13");
asm("NOP");
asm("BIS r14, r14");
asm("SBC r10");
asm("INV r6");
asm("SETZ");
asm("SBC r5");
asm("DEC r13");
asm("INCD.B r13");
asm("SXT r13");
asm("DECD r15");
asm("NOP");
asm("CLRZ");
asm("ADDC.B r8, r12");
asm("SXT r7");
asm("RRA r8");
asm("SXT r13");
asm("AND.B r8, r12");
asm("SUBC.B #-1741, r12");
asm("BIS.B #-10985, r15");
asm("SXT r6");
asm("ADD.B r7, r15");
asm("SWPB r12");
asm("CLRC");
asm("SBC r12");
asm("XOR.B #-9638, r15");
asm("SETZ");
asm("RRA r6");
asm("SUBC.B r11, r5");
asm("NOP");
asm("NOP");
asm("SETC");
asm("ADDC.B #-14085, r5");
asm("SXT.B r8");
asm("SETZ");
asm("DEC.B r6");
asm("XOR.B #22274, r8");
asm("SUB.B #28851, r12");
asm("INC.B r10");
asm("DADD.B #-29884, r8");
asm("DECD r11");
asm("CLRZ");
asm("ADD.B r15, r4");
asm("NOP");
asm("SETC");
asm("MOV.B r14, r13");
asm("SUB.B r12, r12");
asm("RLC r8");
asm("DECD.B r6");
asm("SXT.B r6");
asm("DADC r10");
asm("SBC.B r6");
asm("DADC.B r9");
asm("ADD.B #27873, r6");
asm("CLRC");
asm("RRC.B r10");
asm("INV.B r10");
asm("DADD.B r8, r15");
asm("SUB.B #-7073, r11");
asm("INV r9");
asm("INC.B r5");
asm("CLRN");
asm("BIT.B #25380, r11");
asm("XOR.B #-24105, r14");
asm("NOP");
asm("CLRC");
asm("CMP r15, r14");
asm("INC.B r14");
asm("BIC.B r5, r7");
asm("SETZ");
asm("SBC r11");
asm("ADDC #20572, r14");
asm("CLRZ");
asm("ADDC #32584, r14");
asm("XOR r9, r6");
asm("SWPB.B r5");
asm("AND.B r4, r10");
asm("CLRC");
asm("CLR.B r15");
asm("XOR #5216, r7");
asm("DADD r10, r12");
asm("RLC r4");
asm("AND #-5699, r15");
asm("NOP");
asm("SETZ");
asm("RRA r7");
asm("SETN");
asm("DADD r8, r11");
asm("SXT.B r13");
asm("RRA.B r15");
asm("SWPB.B r11");
asm("SUB r11, r11");
asm("BIC.B #17209, r14");
asm("SETC");
asm("CLRN");
asm("SETZ");
asm("CLR.B r8");
asm("NOP");
asm("CLRC");
asm("CLR.B r4");
asm("DECD.B r6");
asm("INCD r9");
asm("RLC r6");
asm("RLA.B r9");
asm("SETC");
asm("CLRN");
asm("DECD.B r5");
asm("BIT.B r10, r5");
asm("DADD.B r10, r5");
asm("SXT.B r12");
asm("SUB.B r15, r6");
asm("SBC.B r9");
asm("CLRN");
asm("MOV.B r12, r13");
asm("RRA r12");
asm("INCD.B r8");
asm("RLC.B r14");
asm("BIC.B r14, r12");
asm("RRC.B r11");
asm("XOR #-6489, r15");
asm("RLA r14");
asm("BIC.B r4, r4");
asm("INC r6");
asm("CLRC");
asm("RRA.B r10");
asm("MOV.B r12, r9");
asm("DADC.B r8");
asm("CLR r7");
asm("BIC #-30891, r14");
asm("RLA.B r12");
asm("XOR.B r9, r13");
asm("ADDC r5, r6");
asm("DADD.B #5256, r14");
asm("BIS.B #7701, r14");
asm("SBC r12");
asm("SUBC.B r13, r9");
asm("SXT r13");
asm("RLC.B r9");
asm("AND r12, r15");
asm("RLC.B r15");
asm("RRA r7");
asm("TST r10");
asm("NOP");
asm("BIS r9, r11");
asm("BIC r4, r11");
asm("DADC.B r8");
asm("BIS.B r15, r10");
asm("DADC r15");
asm("SUBC r15, r10");
asm("ADD.B #-17527, r15");
asm("SWPB r8");
asm("BIS.B #13135, r15");
asm("SUB.B r5, r10");
asm("XOR.B #-8965, r4");
asm("TST r13");
asm("INC r11");
asm("SETC");
asm("RRA.B r4");
asm("SBC.B r14");
asm("TST r12");
asm("ADD #5695, r15");
asm("CLRZ");
asm("CLR.B r7");
asm("CLRN");
asm("ADD.B #8861, r4");
asm("CLRC");
asm("ADC r13");
asm("CLRZ");
asm("AND #-22287, r15");
asm("SUB #-19336, r7");
asm("INCD r12");
asm("ADDC.B r9, r9");
asm("AND #29297, r9");
asm("DADC r14");
asm("CLRN");
asm("RLA.B r5");
asm("SXT.B r5");
asm("CLRC");
asm("RRA r13");
asm("TST.B r13");
asm("RLC.B r14");
asm("CMP.B #5159, r11");
asm("DEC.B r11");
asm("NOP");
asm("SETZ");
asm("TST r14");
asm("SUBC.B #-6932, r5");
asm("RRA r11");
asm("INC r7");
asm("SUB #29206, r12");
asm("SUB #8943, r13");
asm("ADDC.B #4411, r12");
asm("BIS.B #-4931, r11");
asm("NOP");
asm("SETZ");
asm("TST.B r14");
asm("MOV #-9246, r14");
asm("INCD r7");
asm("XOR.B r4, r14");
asm("DADD.B r13, r15");
asm("CMP r5, r12");
asm("BIT #-15437, r8");
asm("SETC");
asm("CLRC");
asm("BIT.B #-11149, r9");
asm("SETC");
asm("SUB.B r13, r12");
asm("RRA r11");
asm("CLR.B r6");
asm("RLA r10");
asm("MOV #-1387, r10");
asm("DADC.B r15");
asm("SXT.B r6");
asm("DEC r11");
asm("CLRZ");
asm("NOP");
asm("CLR.B r7");
asm("CLRZ");
asm("SXT r15");
asm("INCD.B r15");
asm("CLR r7");
asm("BIS.B #7166, r8");
asm("DADD.B r14, r10");
asm("ADD r4, r11");
asm("XOR #15175, r6");
asm("RRA.B r15");
asm("BIC.B r12, r13");
asm("XOR #30034, r4");
asm("BIS r5, r14");
asm("ADDC #20151, r7");
asm("BIC.B #-7514, r11");
asm("CMP.B #18748, r9");
asm("RRA.B r11");
asm("BIC.B #26214, r5");
asm("CLR r13");
asm("RRC r12");
asm("BIC.B #2885, r5");
asm("INV.B r9");
asm("INV r4");
asm("CLRC");
asm("SUB.B #-16277, r15");
asm("SUBC.B r9, r11");
asm("ADC.B r6");
asm("CMP.B #-32145, r8");
asm("CLRN");
asm("INC.B r11");
asm("SETZ");
asm("CLR.B r15");
asm("CMP.B r5, r11");
asm("DEC.B r15");
asm("SETC");
asm("RRC r6");
asm("RLA r8");
asm("ADDC r13, r10");
asm("INC r7");
asm("SBC.B r10");
asm("RRA r7");
asm("INCD.B r8");
asm("BIS #-5810, r4");
asm("SETC");
asm("RLC r5");
asm("RRC r7");
asm("SETC");
asm("RRA.B r5");
asm("DADD #-15241, r15");
asm("RRC.B r7");
asm("DECD.B r7");
asm("XOR.B #-4860, r15");
asm("BIC r4, r7");
asm("CLRN");
asm("BIT.B r4, r11");
asm("ADC.B r6");
asm("INCD.B r12");
asm("SETC");
asm("SETZ");
asm("SUBC r4, r8");
asm("MOV #22019, r15");
asm("DADD r14, r12");
asm("SWPB.B r9");
asm("SWPB.B r8");
asm("INC.B r7");
asm("RLC r6");
asm("DECD r5");
asm("SBC.B r7");
asm("RRC r5");
asm("CLRZ");
asm("RRA.B r13");
asm("ADDC #28450, r15");
asm("SETC");
asm("TST r12");
asm("RRC r4");
asm("SBC r12");
asm("RLA r10");
asm("SETN");
asm("MOV.B #-8697, r14");
asm("DEC r8");
asm("CLRC");
asm("RLA.B r9");
asm("XOR.B #22491, r11");
asm("INC.B r6");
asm("XOR r5, r15");
asm("BIS r11, r6");
asm("BIT.B r11, r13");
asm("SETC");
asm("MOV r8, r10");
asm("DADC r6");
asm("DECD r6");
asm("NOP");
asm("DECD.B r5");
asm("SETN");
asm("CLRZ");
asm("DADD.B #-24665, r4");
asm("SUBC #20166, r8");
asm("BIS #-27450, r6");
asm("MOV #24356, r9");
asm("CLRZ");
asm("SETC");
asm("RLA r6");
asm("DEC r9");
asm("RRA.B r5");
asm("RRA.B r15");
asm("SETN");
asm("ADC.B r6");
asm("MOV r4, r7");
asm("RRA.B r14");
asm("DADC r10");
asm("AND.B #-6206, r4");
asm("BIC r6, r15");
asm("SETN");
asm("INCD r10");
asm("NOP");
asm("RRA.B r8");
asm("BIT.B r4, r10");
asm("ADC r9");
asm("BIC.B #2998, r10");
asm("RRC.B r5");
asm("DEC r12");
asm("SWPB r11");
asm("SWPB r13");
asm("AND.B #-29657, r5");
asm("CLRN");
asm("RRA r6");
asm("RRA r12");
asm("ADC.B r5");
asm("CLRC");
asm("DEC r14");
asm("BIS.B #-8389, r4");
asm("SETN");
asm("RRC r6");
asm("BIT.B #16101, r9");
asm("CLRZ");
asm("SETZ");
asm("ADDC.B #6389, r4");
asm("CLRN");
asm("SETC");
asm("DADD #8249, r15");
asm("SETN");
asm("BIS #15251, r5");
asm("CLRC");
asm("NOP");
asm("BIC.B r7, r5");
asm("SWPB r12");
asm("CLRC");
asm("SETZ");
asm("RLA.B r10");
asm("SETN");
asm("CMP r5, r6");
asm("AND.B #-20746, r10");
asm("SWPB r6");
asm("ADDC #-11092, r11");
asm("BIS r14, r5");
asm("SWPB r10");
asm("DADD #23793, r14");
asm("AND #26671, r8");
asm("AND.B r13, r10");
asm("DADC.B r4");
asm("SETC");
asm("SETN");
asm("RRA.B r7");
asm("ADD.B #-9627, r8");
asm("RRA r4");
asm("DADC.B r10");
asm("ADC r10");
asm("BIT r12, r9");
asm("CLRZ");
asm("CLRZ");
asm("NOP");
asm("DECD r11");
asm("BIC r10, r4");
asm("CLRC");
asm("SBC r14");
asm("SXT r9");
asm("TST r9");
asm("BIS.B r10, r7");
asm("SWPB r7");
asm("MOV r14, r10");
asm("RLC r6");
asm("TST r6");
asm("INC r9");
asm("AND.B #-7197, r9");
asm("CLRC");
asm("SBC r14");
asm("BIC.B r9, r10");
asm("SETZ");
asm("SETC");
asm("DADC.B r8");
asm("XOR r8, r8");
asm("MOV #-29541, r7");
asm("SBC r14");
asm("DADD.B #26017, r13");
asm("CLRN");
asm("INC.B r9");
asm("ADC r13");
asm("SETZ");
asm("CLRN");
asm("CMP r13, r6");
asm("SBC.B r12");
asm("BIS r4, r9");
asm("BIC r14, r10");
asm("SETZ");
asm("RLC.B r13");
asm("CLR.B r15");
asm("RLA.B r10");
asm("ADD #668, r11");
asm("SUBC #24715, r13");
asm("ADC r11");
asm("ADC.B r15");
asm("RLC.B r9");
asm("CLRN");
asm("XOR #32338, r5");
asm("DEC r4");
asm("ADDC.B r8, r5");
asm("RLC.B r14");
asm("RLA.B r7");
asm("INCD r12");
asm("DADC.B r8");
asm("AND #-29619, r10");
asm("MOV.B r15, r13");
asm("XOR r10, r12");
asm("SETN");
asm("DECD.B r6");
asm("ADDC.B r7, r7");
asm("SXT.B r4");
asm("SETN");
asm("RLC.B r5");
asm("CMP.B #26176, r13");
asm("RLA r13");
asm("ADDC.B #-7478, r13");
asm("CLRZ");
asm("INC.B r12");
asm("DEC.B r11");
asm("SUBC.B #-25513, r10");
asm("SETN");
asm("XOR.B r10, r7");
asm("CLR.B r8");
asm("INCD r8");
asm("ADC r9");
asm("SUBC #-25048, r10");
asm("DEC r12");
asm("RLC r6");
asm("SUB r10, r11");
asm("SETN");
asm("SETN");
asm("TST r6");
asm("BIS r12, r11");
asm("NOP");
asm("BIT.B #32229, r15");
asm("SETC");
asm("CLRZ");
asm("SETC");
asm("DADC r4");
asm("BIC.B r10, r15");
asm("SXT r15");
asm("BIT #-12066, r8");
asm("SUB.B #18693, r4");
asm("NOP");
asm("RLC r11");
asm("RRA.B r7");
asm("ADC.B r8");
asm("SETC");
asm("DEC.B r12");
asm("RRC.B r12");
asm("CLR r11");
asm("DEC.B r8");
asm("RLC.B r8");
asm("BIS.B #6697, r14");
asm("MOV #-11145, r7");
asm("AND #17668, r7");
asm("RRC.B r13");
asm("BIS.B r9, r12");
asm("SXT.B r5");
asm("RRC.B r7");
asm("RLA r12");
asm("CMP.B #-23969, r7");
asm("CLR r4");
asm("DADD #12799, r13");
asm("INV.B r7");
asm("TST.B r9");
asm("ADD #-30035, r13");
asm("RLA.B r5");
asm("CLRZ");
asm("RRA r11");
asm("CLRC");
asm("NOP");
asm("RRA.B r4");
asm("SETN");
asm("SXT.B r9");
asm("SETN");
asm("BIC.B #5241, r13");
asm("INC.B r7");
asm("SXT r7");
asm("INC r10");
asm("DEC r13");
asm("BIT #20820, r14");
asm("INC.B r14");
asm("RRC r14");
asm("DADC.B r5");
asm("SUBC.B r5, r8");
asm("SXT r8");
asm("ADD #-9563, r7");
asm("ADDC #-9220, r12");
asm("NOP");
asm("RRC.B r10");
asm("BIT #3616, r6");
asm("SBC.B r9");
asm("SETZ");
asm("INV.B r14");
asm("ADC r5");
asm("INV.B r10");
asm("RLC.B r11");
asm("BIT r11, r10");
asm("TST.B r10");
asm("SXT.B r13");
asm("ADD r8, r10");
asm("BIS #27063, r7");
asm("SETN");
asm("NOP");
asm("INC r5");
asm("INV.B r11");
asm("ADD #-16310, r15");
asm("MOV r13, r12");
asm("ADD.B r11, r10");
asm("NOP");
asm("CLRC");
asm("DADD #-19183, r4");
asm("DECD.B r6");
asm("SUB.B r15, r4");
asm("AND #25146, r15");
asm("TST.B r9");
asm("DADD #-20817, r4");
asm("INCD r15");
asm("SETZ");
asm("SETC");
asm("INV r5");
asm("SUB.B r13, r15");
asm("RRA.B r11");
asm("MOV r7, r12");
asm("RLC.B r12");
asm("ADDC #-8269, r9");
asm("AND #3888, r7");
asm("SETZ");
asm("SUB r7, r13");
asm("CLRZ");
asm("SETN");
asm("DADC.B r4");
asm("RLC.B r12");
asm("ADDC r13, r14");
asm("DECD r10");
asm("RRA.B r9");
asm("DEC.B r9");
asm("RLC.B r5");
asm("CLRC");
asm("CLRZ");
asm("SETC");
asm("DADC r11");
asm("ADD.B r8, r15");
asm("CLR r7");
asm("SXT.B r8");
asm("SXT r8");
asm("DEC.B r13");
asm("RRA.B r6");
asm("CLRZ");
asm("SUB r8, r10");
asm("NOP");
asm("RLC r7");
asm("CLRZ");
asm("DADD.B #1058, r11");
asm("MOV.B #20584, r5");
asm("INCD r14");
asm("MOV.B r8, r6");
asm("SWPB r7");
asm("XOR #-1244, r14");
asm("SETZ");
asm("BIC #24801, r14");
asm("SUBC.B #-26177, r14");
asm("ADDC r7, r4");
asm("RRC.B r11");
asm("BIT #-16416, r11");
asm("DECD.B r8");
asm("RRC r15");
asm("DEC.B r6");
asm("SETN");
asm("SUB #8603, r5");
asm("CLRN");
asm("CMP r6, r4");
asm("SETZ");
asm("CLRN");
asm("INC.B r14");
asm("INV r9");
asm("SXT.B r7");
asm("INCD.B r6");
asm("INCD.B r14");
asm("SUBC r14, r10");
asm("DADD.B r6, r6");
asm("SXT r11");
asm("RRC.B r7");
asm("ADDC.B r10, r15");
asm("SETN");
asm("SETC");
asm("BIT.B r5, r8");
asm("XOR r12, r13");
asm("SETZ");
asm("ADDC.B r10, r4");
asm("SUB r9, r9");
asm("SWPB.B r10");
asm("CMP.B r12, r4");
asm("CLRZ");
asm("RRC r11");
asm("SETN");
asm("MOV #-30513, r8");
asm("ADC r7");
asm("RLC r11");
asm("DECD r13");
asm("NOP");
asm("BIC #24618, r5");
asm("CLR r15");
asm("SWPB r4");
asm("XOR.B r9, r5");
asm("CLRZ");
asm("NOP");
asm("SXT r5");
asm("SETZ");
asm("SETN");
asm("SXT.B r11");
asm("ADC r7");
asm("CLRN");
asm("CLRC");
asm("CLRC");
asm("SETC");
asm("MOV #559, r12");
asm("INV.B r7");
asm("INV.B r7");
asm("DADD r9, r10");
asm("SBC r11");
asm("AND r12, r14");
asm("SUBC r4, r11");
asm("MOV.B r6, r6");
asm("RRA r11");
asm("MOV #20004, r4");
asm("MOV.B #10667, r5");
asm("DADC r12");
asm("INC r13");
asm("AND.B r13, r14");
asm("DECD.B r5");
asm("BIS.B #-13322, r11");
asm("CLR r13");
asm("TST.B r5");
asm("BIC r8, r14");
asm("INCD r13");
asm("SWPB.B r15");
asm("SBC r5");
asm("SETC");
asm("INC.B r6");
asm("CLRN");
asm("CLRC");
asm("BIS #-15507, r5");
asm("DECD.B r9");
asm("DEC.B r7");
asm("MOV #-27080, r6");
asm("CMP.B #21374, r6");
asm("DADC.B r7");
asm("RLA.B r12");
asm("DECD r14");
asm("AND #10046, r10");
asm("ADD.B #-19060, r15");
asm("CLRC");
asm("CMP r5, r8");
asm("DEC r10");
asm("CLRC");
asm("MOV.B r14, r15");
asm("RRA r11");
asm("INC r12");
asm("SETC");
asm("INCD r12");
asm("RLC.B r9");
asm("SXT r8");
asm("AND.B r4, r5");
asm("SETN");
asm("BIC.B #16662, r9");
asm("DECD r12");
asm("MOV #-16438, r5");
asm("SETZ");
asm("DADC r13");
asm("CLRN");
asm("CLRC");
asm("SETN");
asm("CLRZ");
asm("DADC.B r13");
asm("ADC.B r12");
asm("NOP");
asm("ADDC.B r12, r15");
asm("CLRC");
asm("SUBC #-29158, r15");
asm("RRC r11");
asm("DADD #-3842, r10");
asm("MOV #25706, r7");
asm("INC.B r9");
asm("ADDC #-6889, r14");
asm("ADC r7");
asm("INCD r5");
asm("SETZ");
asm("SETC");
asm("MOV.B r4, r5");
asm("INC r13");
asm("ADC.B r12");
asm("DECD r10");
asm("SWPB.B r10");
asm("ADDC.B #26013, r13");
asm("SETC");
asm("RLC.B r6");
asm("ADC.B r8");
asm("ADC r10");
asm("MOV.B #-1890, r7");
asm("RRC r10");
asm("CLR r4");
asm("SWPB.B r11");
asm("SUB.B r13, r13");
asm("DEC.B r12");
asm("CLR.B r5");
asm("CLRZ");
asm("INCD.B r13");
asm("BIT #25789, r7");
asm("RLC.B r15");
asm("TST.B r13");
asm("DADD #-32654, r6");
asm("CLRZ");
asm("SETC");
asm("BIS.B #3554, r5");
asm("BIS r12, r13");
asm("SUB.B r7, r12");
asm("ADD r5, r13");
asm("RRA.B r13");
asm("RRA r6");
asm("SETC");
asm("DADD r13, r14");
asm("CLRN");
asm("TST r15");
asm("XOR #14315, r13");
asm("NOP");
asm("SETN");
asm("ADC.B r5");
asm("INCD r9");
asm("DEC r4");
asm("ADC.B r6");
asm("AND #21894, r10");
asm("AND.B r12, r11");
asm("CLR.B r13");
asm("CLRZ");
asm("NOP");
asm("ADC.B r4");
asm("DEC r14");
asm("SUB.B r14, r14");
asm("ADDC r6, r10");
asm("DEC.B r11");
asm("NOP");
asm("SETZ");
asm("SETN");
asm("DEC.B r4");
asm("SWPB.B r8");
asm("NOP");
asm("RLC r13");
asm("CLR r8");
asm("INCD.B r15");
asm("INC.B r4");
asm("TST r9");
asm("INCD r14");
asm("SBC r10");
asm("CLRC");
asm("MOV #25874, r6");
asm("AND.B r4, r15");
asm("RRA r12");
asm("XOR.B #6337, r14");
asm("SETN");
asm("DECD r10");
asm("RRC.B r5");
asm("BIC.B r13, r5");
asm("SBC r8");
asm("ADDC #6450, r6");
asm("DADC.B r5");
asm("INC.B r5");
asm("SWPB.B r7");
asm("BIT r8, r11");
asm("DADD r13, r11");
asm("DADD.B #-22625, r11");
asm("RRC.B r12");
asm("DADD #-4976, r14");
asm("BIC #17993, r6");
asm("DEC.B r10");
asm("SUB.B #1468, r13");
asm("INC.B r4");
asm("RRC r12");
asm("INV.B r4");
asm("NOP");
asm("SXT.B r10");
asm("SBC r14");
asm("TST r9");
asm("SBC r5");
asm("SETZ");
asm("INV r15");
asm("SUBC r11, r9");
asm("NOP");
asm("TST.B r13");
asm("NOP");
asm("BIS.B #-24815, r11");
asm("INCD r10");
asm("SUB.B #-16215, r14");
asm("CLRZ");
asm("BIS.B r12, r9");
asm("RRA r15");
asm("INCD.B r14");
asm("CLRZ");
asm("INCD.B r5");
asm("ADC r14");
asm("CLRC");
asm("SBC.B r15");
asm("CLR r7");
asm("SBC.B r13");
asm("SWPB.B r12");
asm("RRA r14");
asm("SUBC.B #21266, r14");
asm("CLRC");
asm("RRC.B r8");
asm("CLR r15");
asm("SWPB.B r5");
asm("ADC r11");
asm("CLR.B r15");
asm("BIC.B #-5162, r8");
asm("CLRC");
asm("DEC.B r6");
asm("DECD.B r11");
asm("SXT r11");
asm("BIS #2689, r13");
asm("SXT r8");
asm("DADC r12");
asm("INC.B r15");
asm("SWPB.B r15");
asm("TST r5");
asm("INCD r14");
asm("BIS.B r10, r15");
asm("SETZ");
asm("ADDC r12, r4");
asm("BIT #-17283, r15");
asm("DEC.B r5");
asm("CLRC");
asm("SBC.B r11");
asm("CLRC");
asm("ADC.B r4");
asm("SUB.B #-4675, r9");
asm("RLA.B r8");
asm("XOR r9, r4");
asm("CLRN");
asm("SETN");
asm("RRA r15");
asm("SBC r8");
asm("ADDC.B #16432, r11");
asm("INV r14");
asm("BIC.B #28376, r13");
asm("BIT #11942, r7");
asm("DECD r14");
asm("CLRN");
asm("DECD r8");
asm("RLC.B r11");
asm("RLC.B r14");
asm("SETC");
asm("RLA.B r10");
asm("SXT.B r6");
asm("SUBC r12, r13");
asm("RRC r4");
asm("TST.B r7");
asm("RLA r4");
asm("ADD #-3151, r7");
asm("CLRC");
asm("DECD.B r14");
asm("CLRN");
asm("BIC #-32202, r5");
asm("SXT r11");
asm("DADC r14");
asm("SETZ");
asm("RLC r10");
asm("XOR #-21419, r15");
asm("SBC r4");
asm("SXT.B r8");
asm("CLRC");
asm("TST r13");
asm("XOR #22958, r14");
asm("CLRC");
asm("INV r7");
asm("AND #20850, r14");
asm("CLRN");
asm("SWPB r9");
asm("SUBC.B r9, r14");
asm("SXT r12");
asm("SXT r12");
asm("DECD r14");
asm("TST r15");
asm("CLRC");
asm("ADC r8");
asm("NOP");
asm("DADD.B r6, r15");
asm("CLRC");
asm("SUB.B r7, r9");
asm("SWPB.B r4");
asm("CLRZ");
asm("DECD.B r13");
asm("INC.B r5");
asm("INC r10");
asm("DEC r15");
asm("SXT r9");
asm("CLRZ");
asm("SXT r4");
asm("CLRN");
asm("SETN");
asm("SWPB r12");
asm("INC r5");
asm("ADC.B r4");
asm("CLRN");
asm("TST.B r10");
asm("INC.B r10");
asm("CMP #-27203, r9");
asm("DEC r8");
asm("DECD.B r9");
asm("MOV.B r9, r5");
asm("SBC r4");
asm("SWPB r12");
asm("CLRN");
asm("ADDC r5, r14");
asm("ADDC.B #25981, r7");
asm("CMP.B r11, r5");
asm("INC.B r9");
asm("RRA.B r14");

        asm volatile (  "pop    r15                                             \n\t"   \
                                        "pop    r14                                             \n\t"   \
                                        "pop    r13                                             \n\t"   \
                                        "pop    r12                                             \n\t"   \
                                        "pop    r11                                             \n\t"   \
                                        "pop    r10                                             \n\t"   \
                                        "pop    r9                                              \n\t"   \
                                        "pop    r8                                              \n\t"   \
                                        "pop    r7                                              \n\t"   \
                                        "pop    r6                                              \n\t"   \
                                        "pop    r5                                              \n\t"   \
                                        "pop    r4                                              \n\t"   \
                                );
                asm("nop");
                asm("nop");
                asm("nop");
                asm("nop");
                asm("nop");
                asm("nop");
                toggleTask(LMM2_TAG);
                asm("nop");
                asm("nop");
                asm("nop");
                asm("nop");
                asm("nop");
                asm("nop");
                for (i = 0; i < ROW_NUM; i ++) {
                        for (j = 0; j < COL_NUM; j ++) {
                                d = 0;
                                for (k = 0; k < P_NUM; k ++) {
                                        d += a2[i*ROW_NUM + k] * b2[k*ROW_NUM + j];
                                }
                                c2[i*ROW_NUM + j] = d;
                        }
                }
                asm("nop");
                asm("nop");
                asm("nop");
                asm("nop");
                for (i = 0; i < ROW_NUM; i ++) {
                        for (j = 0; j < COL_NUM; j ++) {
                                c2[i*ROW_NUM + j] = 0;
                        }
                }

                toggleTask(LMM3_TAG);
                asm("nop");
                asm("nop");
                asm("nop");
                asm("nop");
                asm("nop");
                asm("nop");
                for (i = 0; i < LOOP_NUM; i ++) {
                        c3 = a3 * b3;
                        a3 = b3;
                        b3 = c3;
                }
                asm("nop");
                asm("nop");
                asm("nop");
                asm("nop");
                a3 = 1.1;
                b3 = 0.9;

                toggleTask(LMM4_TAG);
                asm("nop");
                asm("nop");
                asm("nop");
                asm("nop");
                asm("nop");
                asm("nop");
                c4 = gcd(a4, b4);
                asm("nop");
                asm("nop");
                asm("nop");
                asm("nop");
                a4 = P; b4 = Q; c4 = 0;

                toggleTask(LMM5_TAG);
                asm("nop");
                asm("nop");
                asm("nop");
                asm("nop");
                asm("nop");
                asm("nop");
                testqsort(b5, ELE_NUM);
                asm("nop");
                asm("nop");
                asm("nop");
                asm("nop");
                for(i = 0; i < ELE_NUM; i ++) {
                        b5[i] = a5[i];
                }

                toggleTask(LMM6_TAG);
                asm("nop");
                asm("nop");
                asm("nop");
                asm("nop");
                asm("nop");
                asm("nop");
                state = 1;
                while(state % 11) {
                        switch(state % 7) {
                        case 0: state += 2; break;
                        case 1: state *= 3; break;
                        case 2: state -= 5; break;
                        case 3: state += 4; break;
                        case 4: state *= 3; break;
                        case 5: state /= 2; break;
                        case 6: state += 5; break;
                        }
                        if(state < 0)
                                state = -state;
                }
                asm("nop");
                asm("nop");
                asm("nop");
                asm("nop");
                state = 1;

                toggleTask(LMM7_TAG);
                asm("nop");
                asm("nop");
                asm("nop");
                asm("nop");
                asm("nop");
                asm("nop");
                for(i = 3; i < 20; i += 2) {
                        o7 = list_find(head7, i);
                }
                asm("nop");
                asm("nop");
                asm("nop");
                asm("nop");
                o7 = NULL;

                toggleTask(LMM8_TAG);
                asm("nop");
                asm("nop");
                asm("nop");
                asm("nop");
                asm("nop");
                asm("nop");
                o8 = g_list_sort_real(head8);
                asm("nop");
                asm("nop");
                asm("nop");
                asm("nop");
                head8 = &d8[0];
                head8->data = a8[0];
                head8->prev = NULL;
                o8 = head8;
                for (i = 1; i < LIST_LEN8; i ++) {
                        GList* p8;
                        p8 = &d8[i];
                        p8->data = a8[i];
                        o8->next = p8;
                        p8->prev = o8;
                        p8->next = NULL;
                        o8 = p8;
                }
                o8 = NULL;

                toggleTask(LMM9_TAG);
                asm("nop");
                asm("nop");
                asm("nop");
                asm("nop");
                asm("nop");
                asm("nop");
                hash = g_str_hash(a9);
                asm("nop");
                asm("nop");
                asm("nop");
                asm("nop");
                hash = 0;

                toggleTask(LMM10_TAG);
/*                asm("nop");
                asm("nop");
                asm("nop");
                asm("nop");
                asm("nop");
                asm("nop");
                head10 = malloc(sizeof(GList));
                head10->data = a10[0];
                head10->prev = NULL;
                o10 = head10;
                for (i = 1; i < LIST_LEN10; i ++) {
                        GList* p10;
                        p10 = malloc(sizeof(GList));
                        p10->data = a10[i];
                        o10->next = p10;
                        p10->prev = o10;
                        p10->next = NULL;
                        o10 = p10;
                }
                o10 = g_list_sort_real(head10);
                while(NULL != o10) {
                        head10 = o10->next;
                        free(o10);
                        o10 = head10;
                }
                asm("nop");
                asm("nop");
                asm("nop");
                asm("nop");
                head10 = NULL;
                o10 = NULL;*/

                taskEXIT_CRITICAL();
                vTaskDelay(1);
        }
}

