/*
 * port from   FreeRTOS V8.2.3 MSP430-GCC demo
 * 
 *
 * lmm
 * 02142017
 */


/* Standard includes. */
#include <stdlib.h>
#include <signal.h>

#include "omsp.h"

/* Scheduler includes. */
#include "FreeRTOS.h"
#include "task.h"

#include "tasktags.h"

/* applications. */
#include "integer.h"
#include "PollQ.h"

#include "lmm.h"


/* task priorities. */
#define mainCHECK_TASK_PRIORITY			( tskIDLE_PRIORITY + 3 )
#define mainQUEUE_POLL_PRIORITY			( tskIDLE_PRIORITY + 2 )
#define mainLMM_TASK_PRIORITY			( tskIDLE_PRIORITY + 1 )

#define mainNO_ERROR_CHECK_DELAY		( ( TickType_t ) 1000 / portTICK_PERIOD_MS  ) // 30, 3000
#define mainERROR_CHECK_DELAY			( ( TickType_t ) 300 / portTICK_PERIOD_MS  ) // 10, 500

static void vErrorChecks( void *pvParameters );
static short prvCheckOtherTasksAreStillRunning( void );

static void prvSetupHardware( void );

/* Used to detect the idle hook function stalling. */
static volatile unsigned long ulIdleLoops = 0UL;
void vApplicationIdleHook( void );

/*
 * Start the demo application tasks - then start the real time scheduler.
 */
int main(void) {

	prvSetupHardware();

	/* Start application tasks. */
	vStartLMMTasks( mainLMM_TASK_PRIORITY );
	vStartIntegerMathTasks( tskIDLE_PRIORITY );
	vStartPolledQueueTasks( mainQUEUE_POLL_PRIORITY );

	/* Start the 'Check' task which is defined in this file. */
	xTaskCreate( vErrorChecks, "Check", configMINIMAL_STACK_SIZE, NULL, mainCHECK_TASK_PRIORITY, NULL);	

	/* Start the scheduler. */
	vTaskStartScheduler();

	/* As the scheduler has been started the demo applications tasks will be
	executing and we should never get here! */
	tagTask(ERROR_TAG);
	for(;;) ;

      return 0;
}

static void vErrorChecks( void *pvParameters )
{
static volatile unsigned long ulDummyVariable = 3UL;
TickType_t xDelayPeriod = mainNO_ERROR_CHECK_DELAY;

	/* Cycle for ever, delaying then checking all the other tasks are still
	operating without error. */
	for( ;; )
	{
		/* Wait until it is time to check again.  The time we wait here depends
		on whether an error has been detected or not.  When an error is 
		detected the time is shortened resulting in a faster LED flash rate. */
		vTaskDelay( xDelayPeriod );

		toggleTask(Check_TAG); // tagTask(Check_TAG);
		/* Perform a bit of 32bit maths to ensure the registers used by the 
		integer tasks get some exercise outside of the integer tasks 
		themselves. The result here is not important we are just deliberately
		changing registers used by other tasks to ensure that their context
		switch is operating as required. - see the demo application 
		documentation for more info. */
		ulDummyVariable *= 3UL;
		
		/* See if the other tasks are all ok. */
		if( prvCheckOtherTasksAreStillRunning() != pdPASS )
		{
			/* An error occurred in one of the tasks so shorten the delay 
			period - which has the effect of increasing the frequency of the
			LED toggle. */
			xDelayPeriod = mainERROR_CHECK_DELAY;
		}

		/* Flash! */
		//vParTestToggleLED( mainCHECK_LED );
		//untagTask(Check_TAG);
	}
}
/*-----------------------------------------------------------*/

static short prvCheckOtherTasksAreStillRunning( void )
{
static short sNoErrorFound = pdTRUE;
static unsigned long ulLastIdleLoops = 0UL;

	/* The demo tasks maintain a count that increments every cycle of the task
	provided that the task has never encountered an error.  This function 
	checks the counts maintained by the tasks to ensure they are still being
	incremented.  A count remaining at the same value between calls therefore
	indicates that an error has been detected.  Only tasks that do not flash
	an LED are checked. */

	if( xAreIntegerMathsTaskStillRunning() != pdTRUE )
	{
		sNoErrorFound = pdFALSE;
	}
	
	if( xArePollingQueuesStillRunning() != pdTRUE )
	{
		sNoErrorFound = pdFALSE;
	}

	if( ulLastIdleLoops == ulIdleLoops )
	{
		sNoErrorFound = pdFALSE;
	}

	ulLastIdleLoops = ulIdleLoops;
	
	return sNoErrorFound;
}
/*-----------------------------------------------------------*/

static void prvSetupHardware( void )
{
	/* Stop the watchdog.
	WDTCTL = WDTPW + WDTHOLD; */

  LED_CTRL = 0x00; // lmm 
}
/*-----------------------------------------------------------*/

void vApplicationIdleHook( void )
{
	/* Simple put the CPU into lowpower mode. */
	LPM3; //_BIS_SR( LPM3_bits );
	ulIdleLoops++;
}


